<?php
/**
 * class-affiliates-dashboard-campaigns.php
 *
 * Copyright (c) 2010 - 2019 "kento" Karim Rahimpur www.itthinx.com
 *
 * This code is provided subject to the license granted.
 * Unauthorized use and distribution is prohibited.
 * See COPYRIGHT.txt and LICENSE.txt
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * This header and all notices must be kept intact.
 *
 * @author Karim Rahimpur
 * @package affiliates-enterprise
 * @since affiliates-enterprise 4.0.0
 */

if ( !defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Dashboard section: Campaigns
 */
class Affiliates_Dashboard_Campaigns extends Affiliates_Dashboard_Section_Table {

	protected static $section_order = 600;

	protected static $defaults = array(
		'per_page' => self::PER_PAGE_DEFAULT
	);

	private $search = null;

	private $orderby_comp = 'name-asc';

	private $management = 0;

	public static function init() { }

	/**
	 * {@inheritDoc}
	 */
	public static function get_section_order() { return self::$section_order; }

	public function __construct( $params = array() ) { $this->template = 'dashboard/campaigns.php'; $this->require_user_id = true; parent::__construct( $params ); $this->url_parameters = array( 'campaigns-page', 'per_page', 'search', 'orderby', 'order', 'orderby_comp', 'management' ); $this->orderby = 'name'; $this->sort_order = 'ASC'; $this->orderby_comp = 'name-asc'; $this->columns = array( 'name' => array( 'title' => __( 'Name', 'affiliates' ), 'description' => __( 'The name of the campaign.', 'affiliates' ) ), 'description' => array( 'title' => __( 'Description', 'affiliates' ), 'description' => __( 'The description of the campaign.', 'affiliates' ) ), 'hits' => array( 'title' => __( 'Hits', 'affiliates' ), 'description' => __( 'The number of hits or clicks on links related to the campaign.', 'affiliates' ) ), 'visits' => array( 'title' => __( 'Visits', 'affiliates' ), 'description' => __( 'The number of individual daily visits related to the campaign.', 'affiliates' ) ), 'referrals' => array( 'title' => __( 'Referrals', 'affiliates' ), 'description' => __( 'The number of referred transactions related to the campaign.', 'affiliates' ) ), 'totals' => array( 'title' => __( 'Totals', 'affiliates' ), 'description' => __( 'The total commission amounts related to the campaign.', 'affiliates' ) ), 'ratio' => array( 'title' => __( 'Ratio', 'affiliates' ), 'description' => __( 'The conversion ratio for the campaign, expressing the relation between referrals and visits.', 'affiliates' ) ), 'url' => array( 'title' => __( 'URL', 'affiliates' ), 'description' => __( 'The basic referral link related to the campaign.', 'affiliates' ) ), 'campaign_id' => array( 'title' => __( 'ID', 'affiliates' ), 'description' => __( 'The identifier of the campaign.', 'affiliates' ) ) ); }

	/**
	 * Filter by user's search query string ...
	 *
	 * @return string
	 */
	public function get_search() { return $this->search; }

	/**
	 * The composed orderby-order ...
	 *
	 * @return string
	 */
	public function get_orderby_comp() { return $this->orderby_comp; }

	/**
	 * Whether the campaign management should be shown.
	 *
	 * @return boolean
	 */
	public function is_management() { return $this->management > 0; }

	/**
	 * Value of the management flag.
	 *
	 * @return int
	 */
	public function get_management() { return $this->management; }

	public function get_url( $params = array() ) { $IX21466 = ( is_ssl() ? 'https://' : 'http://' ) . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI']; $IX21466 = remove_query_arg( 'clear_filters', $IX21466 ); $IX21466 = remove_query_arg( 'apply_filters', $IX21466 ); $IX21466 = remove_query_arg( 'affiliate_id', $IX21466 ); $IX21466 = remove_query_arg( 'campaign_id', $IX21466 ); $IX21466 = remove_query_arg( '_campaign_id', $IX21466 ); $IX21466 = remove_query_arg( 'action', $IX21466 ); $IX21466 = remove_query_arg( 'action2', $IX21466 ); $IX21466 = remove_query_arg( '_wpnonce', $IX21466 ); $IX21466 = remove_query_arg( '_wp_http_referer', $IX21466 ); foreach ( $this->url_parameters as $IX25997 ) { $IX21466 = remove_query_arg( $IX25997, $IX21466 ); $IX50446 = null; switch ( $IX25997 ) { case 'per_page' : $IX50446 = $this->get_per_page(); break; case 'search' : $IX50446 = $this->get_search(); break; case 'orderby' : $IX50446 = $this->get_orderby(); break; case 'orderby_comp' : $IX50446 = $this->get_orderby_comp(); break; case 'order' : $IX50446 = $this->get_sort_order(); break; case 'management' : $IX50446 = $this->get_management(); break; case 'orderby_comp' : $IX50446 = null; break; } if ( $IX50446 !== null ) { $IX21466 = add_query_arg( $IX25997, $IX50446, $IX21466 ); } } foreach ( $params as $IX17101 => $IX50446 ) { $IX21466 = remove_query_arg( $IX17101, $IX21466 ); if ( $IX50446 !== null ) { $IX21466 = add_query_arg( $IX17101, $IX50446, $IX21466 ); } } return $IX21466; }

	public function render() { $IX76306 = !empty( $_REQUEST['per_page'] ) ? min( max( 1, intval( trim( $_REQUEST['per_page'] ) ) ), self::MAX_PER_PAGE ) : null; if ( $IX76306 !== null ) { $this->per_page = intval( $IX76306 ); } $this->current_page = isset( $_REQUEST['campaigns-page'] ) ? max( 0, intval( $_REQUEST['campaigns-page'] ) ) : 0; $this->management = isset( $_REQUEST['management'] ) && intval( $_REQUEST['management'] ) > 0 ? 1 : 0; if ( isset( $_REQUEST['clear_filters'] ) ) { unset( $_REQUEST['search'] ); $this->search = null; $this->orderby = 'name'; $this->sort_order = 'ASC'; $this->orderby_comp = 'name-asc'; } else { $this->search = !empty( $_REQUEST['search'] ) ? trim( $_REQUEST['search'] ) : null; if ( strlen( $this->search ) === 0 ) { $this->search = null; } $this->orderby_comp = isset( $_REQUEST['orderby_comp'] ) ? $_REQUEST['orderby_comp'] : $this->orderby_comp; if ( strpos( $this->orderby_comp, '-asc' ) !== false ) { $this->orderby = str_replace( '-asc', '', $this->orderby_comp ); $this->sort_order = 'ASC'; $this->switch_sort_order = 'DESC'; } else if ( strpos( $this->orderby_comp, '-desc' ) !== false ) { $this->orderby = str_replace( '-desc', '', $this->orderby_comp ); $this->sort_order = 'DESC'; $this->switch_sort_order = 'ASC'; } switch ( $this->orderby ) { case 'name' : case 'campaign_id' : case 'hits' : case 'visits' : case 'referrals' : case 'ratio' : break; default : $this->orderby = 'name'; $this->sort_order = 'ASC'; $this->switch_sort_order = 'DESC'; $this->orderby_comp = 'name-asc'; } } $IX59790 = $this->get_affiliate_id(); $IX62520 = $this->per_page * $this->current_page; $IX94367 = Affiliates_Campaign::get_campaigns( $IX59790 ); $this->count = count( $IX94367 ); if ( count( $IX94367 ) > 0 ) { $this->entries = array(); $IX20285 = null; if ( $this->search !== null ) { $IX20285 = preg_replace( '/\s+/', ' ', preg_replace( '/[^a-z0-9_-]/', ' ', strtolower( $this->search ) ) ); if ( strlen( $IX20285 ) === 0 ) { $IX20285 = null; } } foreach ( $IX94367 as $IX45172 ) { $IX71571 = $IX45172->get_visits(); $IX98556 = $IX45172->get_referrals(); $IX95541 = $IX98556 > 0 ? $IX98556 / $IX71571 : 0; $IX67852 = $IX45172->get_totals(); if ( !is_array( $IX67852 ) ) { $IX67852 = array(); } $IX46046 = true; if ( $IX20285 !== null ) { $IX84295 = preg_replace( '/\s+/', ' ', preg_replace( '/[^a-z0-9_-]/', ' ', strtolower( $IX45172->name . ' ' . $IX45172->description ) ) ); $IX46046 = strpos( $IX84295, $IX20285 ) !== false; } if ( $IX46046 ) { $this->entries[] = (object) array( 'campaign_id' => $IX45172->campaign_id, 'name' => $IX45172->name, 'description' => $IX45172->description, 'hits' => $IX45172->get_hits(), 'visits' => $IX71571, 'referrals' => $IX98556, 'ratio' => $IX95541, 'totals' => $IX67852, 'url' => $IX45172->get_url(), 'pname' => $IX45172->get_pname(), 'cname' => $IX45172->get_cname() ); } } unset( $IX94367 ); if ( method_exists( __CLASS__, 'sort_by_' . $this->orderby ) ) { if ( $this->entries !== null ) { uasort( $this->entries, array( __CLASS__, 'sort_by_' . $this->orderby ) ); } } if ( $this->sort_order === 'DESC' ) { if ( $this->entries !== null ) { $this->entries = array_reverse( $this->entries ); } } if ( $this->entries !== null ) { $this->entries = array_slice( $this->entries, $IX62520, $this->per_page ); } } parent::render(); }

	public static function sort_by_name( $o1, $o2 ) { return strcmp( $o1->name, $o2->name ); }

	public static function sort_by_campaign_id( $o1, $o2 ) { return $o1->campaign_id - $o2->campaign_id; }

	public static function sort_by_description( $o1, $o2 ) { return strcmp( $o1->description, $o2->description ); }

	public static function sort_by_hits( $o1, $o2 ) { return $o1->hits - $o2->hits; }

	public static function sort_by_visits( $o1, $o2 ) { return $o1->visits - $o2->visits; }

	public static function sort_by_referrals( $o1, $o2 ) { return $o1->referrals - $o2->referrals; }

	public static function sort_by_ratio( $o1, $o2 ) { return $o1->ratio - $o2->ratio; }

	/**
	 * {@inheritDoc}
	 */
	public static function get_name() { return __( 'Campaigns', 'affiliates' ); }

	/**
	 * {@inheritDoc}
	 */
	public static function get_key() { return 'campaigns'; }
}
Affiliates_Dashboard_Campaigns::init();
