<?php
/**
 * class-affiliates-affiliate.php
 *
 * Copyright 2011 "kento" Karim Rahimpur - www.itthinx.com
 *
 * This code is provided subject to the license granted.
 * Unauthorized use and distribution is prohibited.
 * See COPYRIGHT.txt and LICENSE.txt
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * This header and all notices must be kept intact.
 *
 * @author Karim Rahimpur
 * @package affiliates-pro
 * @since affiliates-pro 1.0.0
 */

/**
 * Affiliate abstraction.
 */
abstract class Affiliates_Affiliate implements I_Affiliates_Affiliate {

	/**
	 * Returns affiliate object or null if affiliate not exists.
	 *
	 * @param int $affiliate_id
	 */
	public static function get_affiliate( $affiliate_id ) { global $affiliates_db; $IX80949 = $affiliates_db->get_tablename( 'affiliates' ); $IX47327 = $affiliates_db->get_objects( "SELECT * FROM $IX80949 WHERE affiliate_id = %d", $affiliate_id ); if ( !empty( $IX47327 ) ) { return $IX47327[0]; } else { return null; } }

	/**
	 * Returns the user id for the affiliate.
	 *
	 * @param int $affiliate_id unencoded affiliate id
	 *
	 * @return int user id or false
	 */
	public static function get_affiliate_user_id( $affiliate_id ) { global $affiliates_db; $IX69355 = $affiliates_db->get_tablename( 'affiliates' ); $IX51782 = $affiliates_db->get_tablename( 'affiliates_users' ); return $affiliates_db->get_value( "SELECT $IX51782.user_id FROM $IX51782 LEFT JOIN $IX69355 ON $IX51782.affiliate_id = $IX69355.affiliate_id WHERE $IX51782.affiliate_id = %d AND $IX69355.status ='active'", intval( $affiliate_id ) ); }

	/**
	 * Returns the unencoded affiliate id of the user.
	 *
	 * @param int|object $user (optional) specify a user, if none given false is returned
	 *
	 * @return int affiliate id or false if not an affiliate
	 */
	public static function get_user_affiliate_id( $user_id = null ) { global $affiliates_db; $IX34004 = false; if ( $user_id !== null ) { $IX19878 = $affiliates_db->get_tablename( 'affiliates' ); $IX13892 = $affiliates_db->get_tablename( 'affiliates_users' ); if ( $IX43244 = $affiliates_db->get_value( "SELECT $IX13892.affiliate_id FROM $IX13892 LEFT JOIN $IX19878 ON $IX13892.affiliate_id = $IX19878.affiliate_id WHERE $IX13892.user_id = %d AND $IX19878.status ='active'", intval( $user_id ) ) ) { $IX34004 = $IX43244; } } return $IX34004; }

	/**
	 * Retrieves the value of an affiliate attribute.
	 *
	 * @param int $affiliate_id
	 * @param string $key attribute key
	 *
	 * @return mixed|null
	 */
	public static function get_attribute( $affiliate_id, $key ) { global $affiliates_db; $IX67985 = null; if ( $key = Affiliates_Attributes::validate_key( $key ) ) { $IX73879 = $affiliates_db->get_tablename( "affiliates_attributes" ); $IX67985 = $affiliates_db->get_value( "SELECT attr_value FROM $IX73879 WHERE affiliate_id = %d AND attr_key = %s", intval( $affiliate_id ), $key ); } global $affiliates_attribute_filter; if ( !empty( $affiliates_attribute_filter ) && is_array( $affiliates_attribute_filter ) ) { foreach( $affiliates_attribute_filter as $IX17660 ) { $IX67985 = call_user_func( $IX17660, $IX67985, $affiliate_id, $key ); } } return $IX67985; }

	/**
	 * Can modify the value returned when get_attribute is called.
	 *
	 * @param callable $filter
	 *
	 * @return mixed
	 */
	public static function register_attribute_filter( $filter ) { global $affiliates_attribute_filter; if ( empty( $affiliates_attribute_filter ) ) { $affiliates_attribute_filter = array(); } $affiliates_attribute_filter[] = $filter; }
}
