<?php
/**
 * class-affiliates-referral-controller.php
 *
 * Copyright 2011 "kento" Karim Rahimpur - www.itthinx.com
 *
 * This code is provided subject to the license granted.
 * Unauthorized use and distribution is prohibited.
 * See COPYRIGHT.txt and LICENSE.txt
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * This header and all notices must be kept intact.
 *
 * @author Karim Rahimpur
 * @package affiliates-pro
 * @since affiliates-pro 1.0.0
 */

/**
 * Handles referral evaluation and creation with initialization.
 */
class Affiliates_Referral_Controller {

	/**
	 * Constructor
	 *
	 * @param array $params
	 */
	public function __construct( $params = null ) { }

	/**
	 * Record a referral if service validates a referrer.
	 *
	 * @param array $params
	 * @return int referral ID if recorded, otherwise null
	 */
	public function evaluate( $params = null ) { $IX34585 = null; require_once( AFFILIATES_CORE_LIB . '/class-affiliates-service.php' ); $IX49127 = Affiliates_Service::get_referrer_id(); if ( $IX49127 ) { $IX55744 = Affiliates_Service::get_hit_id(); $params['affiliate_id'] = $IX49127; $params['hit_id'] = $IX55744; $IX34585 = $this->add_referral( $params ); } return $IX34585; }

	/**
	 * Checks with service if there is a referrer.
	 *
	 * @return array holding affiliate_id and optionally hit_id if there is a referrer, otherwise null
	 */
	public function evaluate_referrer() { $IX19461 = null; require_once( AFFILIATES_CORE_LIB . '/class-affiliates-service.php' ); $IX76942 = Affiliates_Service::get_referrer_id(); if ( $IX76942 ) { $IX19461 = array(); $IX19461['affiliate_id'] = $IX76942; if ( $IX20154 = Affiliates_Service::get_hit_id() ) { $IX19461['hit_id'] = $IX20154; } } return $IX19461; }

	/**
	 * Adds a referral.
	 *
	 * @param array $params Accepted parameters ...
	 * @param int $params['affiliate_id'] required
	 * @param int $params['post_id']
	 * @param string $params['description']
	 * @param array $params['data']
	 * @param number $params['base_amount']
	 * @param number $params['amount']
	 * @param string $params['currency_id'] currency code (3 characters)
	 * @param string $params['status'] AFFILIATES_REFERRAL_STATUS_ACCEPTED, AFFILIATES_REFERRAL_STATUS_CLOSED, AFFILIATES_REFERRAL_STATUS_PENDING or AFFILIATES_REFERRAL_STATUS_REJECTED
	 * @param string $params['type']
	 * @param string $params['reference']
	 * @param number $params['reference_amount']
	 * @param boolean $params['test']
	 * @param int $params['hit_id']
	 * @param string $params['integration']
	 * @param array[Affiliates_Referral_Item] $params['referral_items']
	 * @param int $params['time'] null (default, recommended) for current time or a Unix timestamp
	 *
	 * @return int referral ID of the recorded referral, otherwise null
	 */
	public function add_referral( $params = null ) { global $affiliates_db; $IX81176 = null; $IX49997 = array( 'affiliate_id' => null, 'post_id' => null, 'description' => '', 'data' => null, 'base_amount' => null, 'amount' => null, 'currency_id' => null, 'status' => null, 'type' => null, 'reference' => null, 'reference_amount' => null, 'test' => false, 'hit_id' => null, 'integration' => null, 'referral_items' => null, 'time' => null ); $params = array_merge( $IX49997, $params ); $IX12068 = $params['affiliate_id']; $IX28363 = $params['post_id']; $IX25503 = $params['description']; $IX35915 = $params['data']; $IX47817 = $params['base_amount']; $IX41043 = $params['amount']; $IX31736 = $params['currency_id']; $IX10834 = $params['status']; $IX97813 = $params['type']; $IX56658 = $params['reference']; $IX50790 = $params['reference_amount']; $IX26380 = $params['test']; $IX43635 = $params['hit_id']; $IX58937 = $params['integration']; $IX27415 = $params['referral_items']; $IX33774 = time(); if ( $params['time'] !== null ) { $IX33774 = intval( $params['time'] ); } $IX55775 = date( 'Y-m-d H:i:s', $IX33774 ); bcscale( affiliates_get_referral_amount_decimals() ); if ( !empty( $IX12068 ) ) { $IX68737 = new Affiliates_Referral(); $IX68737->affiliate_id = $IX12068; $IX68737->post_id = $IX28363; $IX68737->datetime = $IX55775; $IX68737->description = $IX25503; $IX85158 = wp_get_current_user(); if ( !empty( $IX85158 ) ) { $IX68737->user_id = $IX85158->ID; } $IX98276 = $_SERVER['REMOTE_ADDR']; if ( PHP_INT_SIZE >= 8 ) { if ( $IX13316 = ip2long( $IX98276 ) ) { $IX68737->ip = $IX13316; } } else { if ( $IX13316 = ip2long( $IX98276 ) ) { $IX13316 = sprintf( '%u', $IX13316 ); $IX68737->ip = $IX13316; } } if ( !empty( $IX31736 ) ) { if ( $IX31736 = Affiliates_Utility::verify_currency_id( $IX31736 ) ) { $IX68737->currency_id = $IX31736; } } if ( count( $IX27415 ) > 0 ) { $IX68737->referral_items = $IX27415; $IX68737->compute(); } else if ( !empty( $IX41043 ) ) { if ( $IX41043 = Affiliates_Utility::verify_referral_amount( $IX41043 ) ) { $IX68737->amount = $IX41043; } } if ( !empty( $IX35915 ) ) { $IX68737->data = $IX35915; } if ( !empty( $IX10834 ) && Affiliates_Utility::verify_referral_status_transition( $IX10834, $IX10834 ) ) { $IX68737->status = $IX10834; } else { $IX68737->status = get_option( 'aff_default_referral_status', AFFILIATES_REFERRAL_STATUS_ACCEPTED ); } if ( !empty( $IX97813 ) ) { $IX68737->type = $IX97813; } if ( !empty( $IX56658 ) ) { $IX68737->reference = $IX56658; } if ( !empty( $IX50790 ) ) { $IX68737->reference_amount = $IX50790; } if ( !empty( $IX43635 ) ) { $IX68737->hit_id = intval( $IX43635 ); } $IX68737->integration = $IX58937; $IX81237 = null; require_once( AFFILIATES_CORE_LIB . '/class-affiliates-service.php' ); if ( $IX56912 = Affiliates_Service::get_ids() ) { if ( !empty( $IX56912['affiliate_id'] ) && !empty( $IX56912['campaign_id'] ) ) { if ( $IX56912['affiliate_id'] == $IX12068 ) { $IX81237 = intval( $IX56912['campaign_id'] ); $IX68737->campaign_id = $IX81237; } } } if ( !$IX26380 ) { $IX83873 = array( 'affiliate_id' => $IX68737->affiliate_id, 'post_id' => $IX68737->post_id, 'datetime' => $IX68737->datetime, 'description' => $IX68737->description, 'ip' => $IX68737->ip, 'ipv6' => $IX68737->ipv6, 'user_id' => $IX68737->user_id, 'amount' => $IX68737->amount, 'currency_id' => $IX68737->currency_id, 'data' => $IX68737->data, 'status' => $IX68737->status, 'type' => $IX68737->type, 'reference' => $IX68737->reference, 'reference_amount' => $IX68737->reference_amount, 'campaign_id' => $IX68737->campaign_id, 'hit_id' => $IX68737->hit_id, 'integration' => $IX68737->integration, 'referral_items' => $IX68737->referral_items ); $IX29129 = apply_filters( 'affiliates_record_referral', true, $IX83873 ); if ( $IX29129 ) { if ( !affiliates_is_duplicate_referral( array( 'affiliate_id' => $IX12068, 'amount' => $IX41043, 'currency_id' => $IX31736, 'type' => $IX97813, 'reference' => $IX56658, 'data' => $IX35915 ) ) ) { if ( $IX81176 = $IX68737->create() ) { } } } } } return $IX81176; }

	private function get_rate( $params = null ) { if ( isset( $params['level'] ) && ( $params['level'] === null ) ) { unset( $params['level'] ); } $IX34457 = Affiliates_Rate::get_rate( $params ); return $IX34457; }

	/**
	 * Seek out the appropriate rate according to our rate precedence rules.
	 * 
	 * @param array $params
	 * @return NULL|Affiliates_Rate
	 */
	public function seek_rate( $params = null ) { $IX29815 = !empty( $params['affiliate_id'] ) ? intval( $params['affiliate_id'] ) : null; $IX91776 = !empty( $params['object_id'] ) ? intval( $params['object_id'] ) : null; $IX68211 = !empty( $params['group_id'] ) ? intval( $params['group_id'] ) : null; $IX35525 = !empty( $params['term_id'] ) ? intval( $params['term_id'] ) : null; $IX33167 = isset( $params['level'] ) ? intval( $params['level'] ) : null; $IX46636 = !empty( $params['integration'] ) && is_string( $params['integration'] ) ? trim( $params['integration'] ) : null; if ( $IX68211 === null ) { $IX92179 = !empty( $params['group_ids'] ) && is_array( $params['group_ids'] ) ? array_map( 'intval', $params['group_ids'] ) : null; } else { $IX92179 = array( $IX68211 ); } if ( $IX35525 === null ) { $IX65305 = !empty( $params['term_ids'] ) && is_array( $params['term_ids'] ) ? array_map( 'intval', $params['term_ids'] ) : null; } else { $IX65305 = array( $IX35525 ); } $IX52653 = null; if ( $IX29815 !== null && $IX91776 !== null && $IX46636 !== null ) { $IX52653 = $this->get_rate( array( 'affiliate_id' => $IX29815, 'object_id' => $IX91776, 'integration' => $IX46636, 'level' => $IX33167 ) ); } if ( $IX52653 === null ) { if ( $IX29815 !== null && $IX65305 !== null && $IX46636 !== null ) { foreach( $IX65305 as $IX35525 ) { $IX52653 = $this->get_rate( array( 'affiliate_id' => $IX29815, 'term_id' => $IX35525, 'integration' => $IX46636, 'level' => $IX33167 ) ); if ( $IX52653 !== null ) { break; } } } } if ( $IX52653 === null ) { if ( $IX92179 !== null && $IX91776 !== null && $IX46636 !== null ) { foreach( $IX92179 as $IX68211 ) { $IX52653 = $this->get_rate( array( 'group_id' => $IX68211, 'object_id' => $IX91776, 'integration' => $IX46636, 'level' => $IX33167 ) ); if ( $IX52653 !== null ) { break; } } } } if ( $IX52653 === null ) { if ( $IX92179 !== null && $IX65305 !== null && $IX46636 !== null ) { foreach( $IX92179 as $IX68211 ) { foreach( $IX65305 as $IX35525 ) { $IX52653 = $this->get_rate( array( 'group_id' => $IX68211, 'term_id' => $IX35525, 'integration' => $IX46636, 'level' => $IX33167 ) ); if ( $IX52653 !== null ) { break; } } if ( $IX52653 !== null ) { break; } } } } if ( $IX52653 === null ) { if ( $IX91776 !== null && $IX46636 !== null ) { $IX52653 = $this->get_rate( array( 'object_id' => $IX91776, 'integration' => $IX46636, 'level' => $IX33167 ) ); } } if ( $IX52653 === null ) { if ( $IX65305 !== null && $IX46636 !== null ) { foreach( $IX65305 as $IX35525 ) { $IX52653 = $this->get_rate( array( 'term_id' => $IX35525, 'integration' => $IX46636, 'level' => $IX33167 ) ); if ( $IX52653 !== null ) { break; } } } } if ( $IX52653 === null ) { if ( $IX29815 !== null && $IX46636 !== null ) { $IX52653 = $this->get_rate( array( 'affiliate_id' => $IX29815, 'integration' => $IX46636, 'level' => $IX33167 ) ); } } if ( $IX52653 === null ) { if ( $IX29815 !== null ) { $IX52653 = $this->get_rate( array( 'affiliate_id' => $IX29815, 'level' => $IX33167 ) ); } } if ( $IX52653 === null ) { if ( $IX92179 !== null && $IX46636 !== null ) { foreach( $IX92179 as $IX68211 ) { $IX52653 = $this->get_rate( array( 'group_id' => $IX68211, 'integration' => $IX46636, 'level' => $IX33167 ) ); if ( $IX52653 !== null ) { break; } } } } if ( $IX52653 === null ) { if ( $IX92179 !== null ) { foreach( $IX92179 as $IX68211 ) { $IX52653 = $this->get_rate( array( 'group_id' => $IX68211, 'level' => $IX33167 ) ); if ( $IX52653 !== null ) { break; } } } } if ( $IX52653 === null ) { if ( $IX46636 !== null ) { $IX52653 = Affiliates_Rate::get_rate( array( 'integration' => $IX46636, 'level' => $IX33167 ) ); } } if ( $IX52653 === null ) { $IX52653 = Affiliates_Rate::get_rate( array( 'level' => $IX33167 ) ); } return $IX52653; }
}
