<?php
/**
 * class-affiliates-referral-item.php
 *
 * Copyright 2017 "kento" Karim Rahimpur - www.itthinx.com
 *
 * This code is provided subject to the license granted.
 * Unauthorized use and distribution is prohibited.
 * See COPYRIGHT.txt and LICENSE.txt
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * This header and all notices must be kept intact.
 *
 * @author Karim Rahimpur
 * @package affiliates-pro
 * @since affiliates-pro 3.0.0
 */

/**
 * Implements the referral item object.
 */
class Affiliates_Referral_Item implements I_Affiliates_Referral_Item {

	/**
	 * The referral item's ID.
	 * 
	 * @var int $referral_item_id
	 */
	private $referral_item_id = null;

	/**
	 * The related referral's ID.
	 * @var int $referral_id
	 */
	private $referral_id = null;

	/**
	 * The referral item's amount.
	 * @var string
	 */
	private $amount = null;

	/**
	 * The three-letter currency ID.
	 * @var string $currency_id
	 */
	private $currency_id = null;

	/**
	 * The ID of the rate used to calculate the amount of this referral item.
	 * @var int
	 */
	private $rate_id = null;

	/**
	 * The type of this referral item.
	 * @var string
	 */
	private $type = null;

	/**
	 * The line item reference related to this referral item. For example, the ID
	 * of the line item in an order, the form submission ID, the ID of a booking, ...
	 *
	 * @var string
	 */
	private $reference = null;

	/**
	 * The amount of the corresponding line item.
	 * 
	 * @var string
	 */
	private $line_amount = null;

	/**
	 * The ID of the object related to this referral item, for example,
	 * the ID of the product, the form, the event, ...
	 *
	 * @var int
	 */
	private $object_id = null;

	/**
	 * Initializes the $referral_item with the values from $o.
	 * 
	 * @param Affiliates_Referral_Item $referral_item
	 * @param Affiliates_Referral_Item $o
	 */
	private static function initialize( &$referral_item, $o ) { if ( isset( $o->referral_item_id ) ) { $referral_item->referral_item_id = $o->referral_item_id; } if ( isset( $o->referral_id ) ) { $referral_item->referral_id = $o->referral_id; } if ( isset( $o->amount ) ) { $referral_item->amount = $o->amount; } if ( isset( $o->currency_id ) ) { $referral_item->currency_id = $o->currency_id; } if ( isset( $o->rate_id ) ) { $referral_item->rate_id = $o->rate_id; } if ( isset( $o->type ) ) { $referral_item->type = $o->type; } if ( isset( $o->reference ) ) { $referral_item->reference = $o->reference; } if ( isset( $o->line_amount ) ) { $referral_item->line_amount = $o->line_amount; } if ( isset( $o->object_id ) ) { $referral_item->object_id = $o->object_id; } }

	/**
	 * Create the object with the properties provided in $attributes.
	 * $attributes can hold values for these keys:
	 * - referral_item_id
	 * - referral_id
	 * - rate_id
	 * - amount
	 * - currency_id
	 * - type
	 * - reference
	 * - object_id
	 * 
	 * @param array|object $attributes array of key-value pairs or object with appropriate properties
	 */
	public function __construct( $attributes = array() ) { if ( is_object( $attributes ) ) { $attributes = (array) $attributes; } foreach( $attributes as $IX85738 => $IX79266 ) { switch( $IX85738 ) { case 'referral_item_id' : case 'referral_id' : case 'rate_id' : case 'amount' : case 'currency_id' : case 'type' : case 'reference' : case 'line_amount' : case 'object_id' : $this->$IX85738 = $IX79266; break; } } }

	public function __get( $name ) { $IX31109 = null; switch( $name ) { case 'referral_item_id' : case 'referral_id' : case 'rate_id' : case 'amount' : case 'currency_id' : case 'type' : case 'reference' : case 'line_amount' : case 'object_id' : $IX31109 = $this->$name; break; } return $IX31109; }

	public function __set( $name, $value ) { switch( $name ) { case 'referral_item_id' : case 'referral_id' : case 'rate_id' : case 'object_id' : $this->$name = ( $value !== null ? intval( $value ) : null ); break; case 'amount' : $this->amount = bcadd( '0', $value , affiliates_get_referral_amount_decimals() ); break; case 'currency_id' : $this->currency_id = Affiliates_Utility::verify_currency_id( $value ); break; case 'type' : if ( is_string( $value ) ) { $this->type = $value; } break; case 'reference' : if ( is_string( $value ) || is_numeric( $value ) ) { $this->reference = $value; } case 'line_amount' : $this->line_amount = bcadd( '0', $value , affiliates_get_referral_amount_decimals() ); break; } return $value; }

	/**
	 * Create the referral item in the database.
	 * 
	 * @return int referral_item_id on success or null on failure
	 */
	public function create() { global $affiliates_db; if ( $this->referral_item_id === null ) { if ( !empty( $this->referral_id ) ) { $IX61167 = array(); $IX73344 = array(); if ( $this->referral_id !== null ) { $IX61167[] = 'referral_id = %d'; $IX73344[] = intval( $this->referral_id ); } else { $IX61167[] = 'referral_id = NULL'; } if ( $this->amount !== null ) { $IX61167[] = 'amount = %s'; $IX73344[] = $this->amount; } else { $IX61167[] = 'amount = NULL'; } if ( $this->currency_id !== null ) { $IX61167[] = 'currency_id = %s'; $IX73344[] = $this->currency_id; } else { $IX61167[] = 'currency_id = NULL'; } if ( $this->rate_id !== null ) { $IX61167[] = 'rate_id = %d'; $IX73344[] = intval( $this->rate_id ); } else { $IX61167[] = 'rate_id = NULL'; } if ( $this->type !== null ) { $IX61167[] = 'type = %s'; $IX73344[] = $this->type; } else { $IX61167[] = 'type = NULL'; } if ( $this->reference !== null ) { $IX61167[] = 'reference = %s'; $IX73344[] = $this->reference; } else { $IX61167[] = 'reference = NULL'; } if ( $this->line_amount !== null ) { $IX61167[] = 'line_amount = %s'; $IX73344[] = $this->line_amount; } else { $IX61167[] = 'line_amount = NULL'; } if ( $this->object_id !== null ) { $IX61167[] = 'object_id = %d'; $IX73344[] = intval( $this->object_id ); } else { $IX61167[] = 'object_id = NULL'; } $IX12779 = $affiliates_db->get_tablename( 'referral_items' ); $IX23445 = "INSERT INTO $IX12779 SET " . implode( ',', $IX61167 ); if ( $affiliates_db->query( $IX23445, $IX73344 ) ) { $this->referral_item_id = $affiliates_db->get_value( "SELECT LAST_INSERT_ID()" ); } } } return $this->referral_item_id; }

	/**
	 * Read a referral item from the database.
	 * 
	 * @param int $referral_item_id
	 * @return Affiliates_Referral_Item on success or null
	 */
	public function read( $referral_item_id ) { global $affiliates_db; $IX30219 = null; $IX54467 = $affiliates_db->get_tablename( 'referral_items' ); if ( $IX44344 = $affiliates_db->get_objects( "SELECT * FROM $IX54467 WHERE referral_item_id = %d", intval( $referral_item_id ) ) ) { if ( $IX71791 = array_shift( $IX44344 ) ) { self::initialize( $this, $IX71791 ); $IX30219 = $this; } } return $IX30219; }

	/**
	 * Update the database entry based on this object's current values.
	 * @return boolean true on success
	 */
	public function update() { global $affiliates_db; $IX40787 = false; if ( $this->referral_item_id !== null ) { $IX91591 = array(); $IX87860 = array(); if ( $this->referral_id !== null ) { $IX91591[] = 'referral_id = %d'; $IX87860[] = intval( $this->referral_id ); } else { $IX91591[] = 'referral_id = NULL'; } if ( $this->amount !== null ) { $IX91591[] = 'amount = %s'; $IX87860[] = $this->amount; } else { $IX91591[] = 'amount = NULL'; } if ( $this->currency_id !== null ) { $IX91591[] = 'currency_id = %s'; $IX87860[] = $this->currency_id; } else { $IX91591[] = 'currency_id = NULL'; } if ( $this->rate_id !== null ) { $IX91591[] = 'rate_id = %d'; $IX87860[] = intval( $this->rate_id ); } else { $IX91591[] = 'rate_id = NULL'; } if ( $this->type !== null ) { $IX91591[] = 'type = %s'; $IX87860[] = $this->type; } else { $IX91591[] = 'type = NULL'; } if ( $this->reference !== null ) { $IX91591[] = 'reference = %s'; $IX87860[] = $this->reference; } else { $IX91591[] = 'reference = NULL'; } if ( $this->line_amount !== null ) { $IX91591[] = 'line_amount = %s'; $IX87860[] = $this->line_amount; } else { $IX91591[] = 'line_amount = NULL'; } if ( $this->object_id !== null ) { $IX91591[] = 'object_id = %d'; $IX87860[] = intval( $this->object_id ); } else { $IX91591[] = 'object_id = NULL'; } $IX87860[] = intval( $this->referral_item_id ); $IX24894 = $affiliates_db->get_tablename( 'referral_items' ); $IX61348 = "UPDATE $IX24894 SET " . implode( ',', $IX91591 ) . " WHERE referral_item_id = %d"; if ( $affiliates_db->query( $IX61348, $IX87860 ) ) { $IX40787 = true; } } return $IX40787; }

	/**
	 * Delete the entry from the database corresponding to the current object.
	 * Requires this object's referral_item_id to be set.
	 * @return boolean true on success
	 */
	public function delete() { global $affiliates_db; $IX21272 = false; if ( $this->referral_item_id !== null ) { $IX87941 = $affiliates_db->get_tablename( 'referral_items' ); if ( $affiliates_db->query( "DELETE FROM $IX87941 " . "WHERE referral_item_id = %d", intval( $this->referral_item_id ) ) ) { $IX21272 = true; } } return $IX21272; }

}
