<?php
/**
 * class-affiliates-referral.php
 *
 * Copyright 2011 "kento" Karim Rahimpur - www.itthinx.com
 *
 * This code is provided subject to the license granted.
 * Unauthorized use and distribution is prohibited.
 * See COPYRIGHT.txt and LICENSE.txt
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * This header and all notices must be kept intact.
 *
 * @author Karim Rahimpur
 * @package affiliates-pro
 * @since affiliates-pro 1.0.0
 */

/**
 * Referral base.
 */
class Affiliates_Referral {

	private $referral_id = null;
	private $affiliate_id = null;
	private $post_id = null;
	private $datetime = null;
	private $description = null;
	private $ip = null;
	private $ipv6 = null;
	private $user_id = null;
	private $amount = null;
	private $currency_id = null;
	private $data = null;
	private $status = null;
	private $type = null;
	private $reference = null;
	private $reference_amount = null;
	private $campaign_id = null;
	private $hit_id = null;
	private $integration = null;

	/**
	 * Related referral items.
	 *
	 * @var array of Affiliates_Referral_Item $referral_items
	 */
	private $referral_items = null;

	const DEFAULT_REFERRAL_CALCULATION_KEY   = 'aff_def_ref_calc_key';
	const DEFAULT_REFERRAL_CALCULATION_VALUE = 'aff_def_ref_calc_value';

	/**
	 * @legacy used in Affiliates_Referral_WordPress
	 */
	private $referral = null;

	private static $referral_amount_methods = array();

	public static function init() { self::register_referral_amount_method( array( __CLASS__, 'example_referral_amount_method' ) ); }

	/**
	 * Initializes the $referral with the values from $o.
	 *
	 * @param Affiliates_Referral $referral_item
	 * @param object $o
	 */
	private static function initialize( &$referral, $o ) { if ( isset( $o->referral_id ) ) { $referral->referral_id = $o->referral_id; } if ( isset( $o->affiliate_id ) ) { $referral->affiliate_id = $o->affiliate_id; } if ( isset( $o->post_id ) ) { $referral->post_id = $o->post_id; } if ( isset( $o->datetime ) ) { $referral->datetime = $o->datetime; } if ( isset( $o->description ) ) { $referral->description = $o->description; } if ( isset( $o->ip ) ) { $referral->ip = $o->ip; } if ( isset( $o->ipv6 ) ) { $referral->ipv6 = $o->ipv6; } if ( isset( $o->user_id ) ) { $referral->user_id = $o->user_id; } if ( isset( $o->amount ) ) { $referral->amount = $o->amount; } if ( isset( $o->currency_id ) ) { $referral->currency_id = $o->currency_id; } if ( isset( $o->data ) ) { if ( $IX72888 = @unserialize( $o->data ) ) { $referral->data = $IX72888; } else { $referral->data = $o->data; } } if ( isset( $o->status ) ) { $referral->status = $o->status; } if ( isset( $o->type ) ) { $referral->type = $o->type; } if ( isset( $o->reference ) ) { $referral->reference = $o->reference; } if ( isset( $o->reference_amount ) ) { $referral->reference_amount = $o->reference_amount; } if ( isset( $o->campaign_id ) ) { $referral->campaign_id = $o->campaign_id; } if ( isset( $o->hit_id ) ) { $referral->hit_id = $o->hit_id; } if ( isset( $o->integration ) ) { $referral->integration = $o->integration; } if ( isset( $o->referral_items ) ) { if ( is_array( $o->referral_items ) ) { $referral->referral_items = array(); foreach( $o->referral_items as $IX13320 ) { if ( $IX13320 instanceof Affiliates_Referral_item ) { $referral->referral_items[] = $IX13320; } } } } if ( isset( $o->referral ) ) { $referral->referral = $o->referral; } }

	/**
	 * Create the object with the properties provided in $attributes.
	 * $attributes can hold values for these keys:
	 * - referral_id
	 * - affiliate_id
	 * - post_id
	 * - datetime
	 * - description
	 * - ip
	 * - ipv6
	 * - user_id
	 * - amount
	 * - currency_id
	 * - data
	 * - status
	 * - type
	 * - reference
	 * - reference_amount
	 * - campaign_id
	 * - hit_id
	 * - integration
	 *
	 * @legacy
	 * - referral
	 *
	 * @param array|object $attributes array of key-value pairs or object with appropriate properties
	 */
	public function __construct( $attributes = array() ) { if ( is_object( $attributes ) ) { $attributes = (array) $attributes; } foreach( $attributes as $IX44225 => $IX31417 ) { switch( $IX44225 ) { case 'referral_id' : case 'affiliate_id' : case 'post_id' : case 'datetime' : case 'description' : case 'ip' : case 'ipv6' : case 'user_id' : case 'amount' : case 'currency_id' : case 'data' : case 'status' : case 'type' : case 'reference' : case 'reference_amount' : case 'campaign_id' : case 'hit_id' : case 'integration' : case 'referral_items' : case 'referral' : $this->$IX44225 = $IX31417; break; } } }

	/**
	 * @deprecated since 4.0.0 - use rate formulas instead
	 */
	public static function example_referral_amount_method( $affiliate_id = null, $parameters = null ) { $IX18104 = "0"; if ( isset( $parameters['base_amount'] ) ) { $IX18104 = bcmul( "0.1", $parameters['base_amount'] ); } return $IX18104; }

	/**
	 * Registers a referral amount method.
	 *
	 * The method must take two parameters:
	 * 1. int the affiliate id which can be null
	 * 2. array parameters indexed by their name (arguments to add_referral(...)
	 *
	 * @param string|array $method
	 *
	 * @return boolean true if the method is accepted, false otherwise
	 *
	 * @deprecated since 4.0.0 - use rate formulas instead
	 */
	public static function register_referral_amount_method( $method ) { $IX20554 = false; if ( is_string( $method ) ) { $method = explode( "::", $method ); if ( count( $method ) == 1 ) { $method = $method[0]; } } if ( in_array( $method, self::$referral_amount_methods ) ) { $IX20554 = true; } else if ( ( ( is_array( $method ) && ( count( $method ) == 2 ) && method_exists( $method[0], $method[1] ) ) ) || ( is_string( $method ) && function_exists( $method ) ) ) { $IX15359 = bcadd( "0", call_user_func( $method, null, null ) ); if ( $IX15359 !== false ) { self::$referral_amount_methods[] = $method; $IX20554 = true; } } return $IX20554; }

	/**
	 * @deprecated since 4.0.0 - use rate formulas instead
	 */
	public static function get_referral_amount_methods() { return self::$referral_amount_methods; }

	/**
	 * @deprecated since 4.0.0 - use rate formulas instead
	 */
	public static function is_referral_amount_method( $method ) { return self::get_referral_amount_method( $method ); }

	/**
	 * @deprecated since 4.0.0 - use rate formulas instead
	 */
	public static function get_referral_amount_method( $method ) { $IX91511 = @unserialize( $method ); if ( $IX91511 !== false ) { $method = $IX91511; } if ( is_string( $method ) ) { $method = explode( "::", $method ); if ( count( $method ) == 1 ) { $method = $method[0]; } } if ( in_array( $method, self::$referral_amount_methods ) ) { return $method; } else { return false; } }

	/**
	 * Returns the named property's value if valid.
	 * 
	 * @param string $name property name
	 * @return mixed property value
	 */
	public function __get( $name ) { $IX10293 = null; switch( $name ) { case 'referral_id' : case 'affiliate_id' : case 'post_id' : case 'datetime' : case 'description' : case 'ip' : case 'ipv6' : case 'user_id' : case 'amount' : case 'currency_id' : case 'data' : case 'status' : case 'type' : case 'reference' : case 'reference_amount' : case 'campaign_id' : case 'hit_id' : case 'integration' : case 'referral_items' : case 'referral' : $IX10293 = $this->$name; break; } return $IX10293; }

	/**
	 * Sets the named property's value if valid.
	 *
	 * @param string $name property's name
	 * @param mixed $value property's value to set
	 */
	public function __set( $name, $value ) { switch( $name ) { case 'referral_id' : case 'affiliate_id' : case 'post_id' : case 'datetime' : case 'description' : case 'ip' : case 'ipv6' : case 'user_id' : case 'amount' : case 'currency_id' : case 'data' : case 'status' : case 'type' : case 'reference' : case 'reference_amount' : case 'campaign_id' : case 'hit_id' : case 'integration' : case 'referral' : $this->$name = $value; break; case 'referral_items' : if ( is_array( $value ) ) { $this->referral_items = array(); foreach( $value as $IX29364 ) { if ( $IX29364 instanceof Affiliates_Referral_item ) { $this->referral_items[] = $IX29364; } } } break; } }

	/**
	 * Create the referral (and its referral items) in the database.
	 * This will update the referral's amount automatically if there
	 * are any referral items.
	 *
	 * @return int referral_id on success or null on failure
	 */
	public function create() { global $affiliates_db; if ( $this->referral_id === null ) { $this->compute(); $IX71480 = array(); $IX63142 = array(); if ( $this->affiliate_id !== null ) { $IX71480[] = 'affiliate_id = %d'; $IX63142[] = intval( $this->affiliate_id ); } else { } if ( $this->post_id !== null ) { $IX71480[] = 'post_id = %d'; $IX63142[] = intval( $this->post_id ); } else { } if ( $this->datetime !== null ) { $IX71480[] = 'datetime = %s'; $IX63142[] = $this->datetime; } else { $IX71480[] = 'datetime = %s'; $IX63142[] = date( 'Y-m-d H:i:s', time() ); } if ( $this->description !== null ) { $IX71480[] = 'description = %s'; $IX63142[] = $this->description; } else { $IX71480[] = 'description = NULL'; } if ( $this->ip !== null ) { $IX71480[] = 'ip = %d'; $IX63142[] = intval( $this->ip ); } else { $IX71480[] = 'ip = NULL'; } if ( $this->ipv6 !== null ) { $IX71480[] = 'ipv6 = %s'; $IX63142[] = $this->ipv6; } else { $IX71480[] = 'ipv6 = NULL'; } if ( $this->user_id !== null ) { $IX71480[] = 'user_id = %d'; $IX63142[] = intval( $this->user_id ); } else { $IX71480[] = 'user_id = NULL'; } if ( $this->amount !== null ) { $IX71480[] = 'amount = %s'; $IX63142[] = $this->amount; } else { $IX71480[] = 'amount = NULL'; } if ( $this->currency_id !== null ) { $IX71480[] = 'currency_id = %s'; $IX63142[] = $this->currency_id; } else { $IX71480[] = 'currency_id = NULL'; } if ( $this->data !== null ) { $IX71480[] = 'data = %s'; if ( !empty( $this->data ) && is_array( $this->data ) ) { $IX63142[] = serialize( $this->data ); } else if ( !empty( $this->data ) && is_string( $this->data ) ) { $IX63142[] = $this->data; } else { $IX63142[] = ''; } } else { $IX71480[] = 'data = NULL'; } if ( $this->status !== null ) { $IX71480[] = 'status = %s'; $IX63142[] = $this->status; } else { } if ( $this->type !== null ) { $IX71480[] = 'type = %s'; $IX63142[] = $this->type; } else { $IX71480[] = 'type = NULL'; } if ( $this->reference !== null ) { $IX71480[] = 'reference = %s'; $IX63142[] = $this->reference; } else { $IX71480[] = 'reference = NULL'; } if ( $this->reference_amount !== null ) { $IX71480[] = 'reference_amount = %s'; $IX63142[] = $this->reference_amount; } else { $IX71480[] = 'reference_amount = NULL'; } if ( $this->campaign_id !== null ) { $IX71480[] = 'campaign_id = %d'; $IX63142[] = intval( $this->campaign_id ); } else { $IX71480[] = 'campaign_id = NULL'; } if ( $this->hit_id !== null ) { $IX71480[] = 'hit_id = %d'; $IX63142[] = intval( $this->hit_id ); } else { $IX71480[] = 'hit_id = NULL'; } if ( $this->integration !== null ) { $IX71480[] = 'integration = %s'; $IX63142[] = $this->integration; } else { $IX71480[] = 'integration = NULL'; } $IX13303 = $affiliates_db->get_tablename( 'referrals' ); $IX26615 = "INSERT INTO $IX13303 SET " . implode( ',', $IX71480 ); if ( $affiliates_db->query( $IX26615, $IX63142 ) ) { if ( $this->referral_id = $affiliates_db->get_value( "SELECT LAST_INSERT_ID()" ) ) { if ( !empty( $this->referral_items ) && is_array( $this->referral_items ) ) { foreach( $this->referral_items as $IX27925 ) { $IX27925->referral_id = $this->referral_id; $IX27925->create(); } } do_action( 'affiliates_referral', $this->referral_id, array( 'affiliate_id' => $this->affiliate_id, 'post_id' => $this->post_id, 'description' => $this->description, 'data' => $this->data, 'amount' => $this->amount, 'currency_id' => $this->currency_id, 'status' => $this->status, 'type' => $this->type, 'reference' => $this->reference, 'reference_amount' => $this->reference_amount, 'hit_id' => $this->hit_id, 'integration' => $this->integration, 'campaign_id' => $this->campaign_id ) ); } } } return $this->referral_id; }

	/**
	 * Read a referral (and its referral items) from the database.
	 *
	 * @param int $referral_id
	 * @return Affiliates_Referral on success or null
	 */
	public function read( $referral_id ) { global $affiliates_db; $IX84543 = null; $IX84551 = $affiliates_db->get_tablename( 'referrals' ); if ( $IX31761 = $affiliates_db->get_objects( "SELECT * FROM $IX84551 WHERE referral_id = %d", intval( $referral_id ) ) ) { if ( $IX17080 = array_shift( $IX31761 ) ) { self::initialize( $this, $IX17080 ); $this->referral_items = array(); $IX85527 = $affiliates_db->get_tablename( 'referral_items' ); if ( $IX89952 = $affiliates_db->get_objects( "SELECT * FROM $IX85527 WHERE referral_id = %d", intval( $referral_id ) ) ) { if ( !empty( $IX89952 ) && is_array( $IX89952 ) ) { foreach( $IX89952 as $IX18836 ) { $this->referral_items[] = new Affiliates_Referral_Item( $IX18836 ); } } } $IX84543 = $this; } } return $IX84543; }

	/**
	 * Retrieve an array of matching referral IDs.
	 *
	 * @param string $reference
	 *
	 *@return array of int
	 */
	public static function get_ids_by_reference( $reference ) { global $affiliates_db; $IX48860 = array(); $IX49429 = $affiliates_db->get_tablename( 'referrals' ); $IX25121 = $affiliates_db->get_objects( "SELECT referral_id FROM $IX49429 WHERE reference = %s", $reference ); if ( $IX25121 ) { foreach( $IX25121 as $IX52691 ) { $IX48860[] = $IX52691->referral_id; } } return $IX48860; }

	/**
	 * Update the database entry based on this object's current values.
	 * This also creates or updates this referral's referral items and deletes those
	 * that are not present in the object.
	 * This will update the referral's amount automatically if there
	 * are any referral items.
	 *
	 * @return boolean true on success
	 */
	public function update() { global $affiliates_db; $IX26283 = false; $IX55443 = array(); if ( is_array( $this->referral_items ) ) { foreach( $this->referral_items as $IX57687 ) { if ( is_int( $IX57687->referral_item_id ) ) { $IX57687->update(); } else { $IX57687->create(); } if ( $IX57687->referral_item_id ) { $IX55443[] = $IX57687->referral_item_id; } } } $IX99238 = $affiliates_db->get_tablename( 'referral_items' ); $IX55443 = array_map( 'intval', $IX55443 ); $IX78348 = "DELETE FROM $IX99238 WHERE referral_id = %d"; if ( count( $IX55443 ) > 0 ) { $IX78348 .= " AND referral_item_id NOT IN (" . implode( ',', $IX55443 ) . ")"; } $affiliates_db->query( $IX78348, intval( $this->referral_id ) ); if ( $this->referral_id !== null ) { $IX14340 = new Affiliates_Referral(); $IX14340->read( $this->referral_id ); $this->compute(); $IX68219 = array(); $IX31458 = array(); if ( $this->affiliate_id !== null ) { $IX68219[] = 'affiliate_id = %d'; $IX31458[] = intval( $this->affiliate_id ); } else { } if ( $this->post_id !== null ) { $IX68219[] = 'post_id = %d'; $IX31458[] = intval( $this->post_id ); } else { } if ( $this->datetime !== null ) { $IX68219[] = 'datetime = %s'; $IX31458[] = $this->datetime; } else { } if ( $this->description !== null ) { $IX68219[] = 'description = %s'; $IX31458[] = $this->description; } else { $IX68219[] = 'description = NULL'; } if ( $this->ip !== null ) { $IX68219[] = 'ip = %d'; $IX31458[] = intval( $this->ip ); } else { $IX68219[] = 'ip = NULL'; } if ( $this->ipv6 !== null ) { $IX68219[] = 'ipv6 = %s'; $IX31458[] = $this->ipv6; } else { $IX68219[] = 'ipv6 = NULL'; } if ( $this->user_id !== null ) { $IX68219[] = 'user_id = %d'; $IX31458[] = intval( $this->user_id ); } else { $IX68219[] = 'user_id = NULL'; } if ( $this->amount !== null ) { $IX68219[] = 'amount = %s'; $IX31458[] = $this->amount; } else { $IX68219[] = 'amount = NULL'; } if ( $this->currency_id !== null ) { $IX68219[] = 'currency_id = %s'; $IX31458[] = $this->currency_id; } else { $IX68219[] = 'currency_id = NULL'; } if ( $this->data !== null ) { $IX68219[] = 'data = %s'; if ( !empty( $this->data ) && is_array( $this->data ) ) { $IX31458[] = serialize( $this->data ); } else if ( !empty( $this->data ) && is_string( $this->data ) ) { $IX31458[] = $this->data; } else { $IX31458[] = ''; } } else { $IX68219[] = 'data = NULL'; } if ( $this->status !== null ) { $IX68219[] = 'status = %s'; $IX31458[] = $this->status; } else { } if ( $this->type !== null ) { $IX68219[] = 'type = %s'; $IX31458[] = $this->type; } else { $IX68219[] = 'type = NULL'; } if ( $this->reference !== null ) { $IX68219[] = 'reference = %s'; $IX31458[] = $this->reference; } else { $IX68219[] = 'reference = NULL'; } if ( $this->reference_amount !== null ) { $IX68219[] = 'reference_amount = %s'; $IX31458[] = $this->reference_amount; } else { $IX68219[] = 'reference_amount = NULL'; } if ( $this->campaign_id !== null ) { $IX68219[] = 'campaign_id = %d'; $IX31458[] = intval( $this->campaign_id ); } else { $IX68219[] = 'campaign_id = NULL'; } if ( $this->hit_id !== null ) { $IX68219[] = 'hit_id = %d'; $IX31458[] = intval( $this->hit_id ); } else { $IX68219[] = 'hit_id = NULL'; } if ( $this->integration !== null ) { $IX68219[] = 'integration = %s'; $IX31458[] = $this->integration; } else { $IX68219[] = 'integration = NULL'; } $IX31458[] = intval( $this->referral_id ); $IX74294 = $affiliates_db->get_tablename( 'referrals' ); $IX78348 = "UPDATE $IX74294 SET " . implode( ',', $IX68219 ) . " WHERE referral_id = %d"; if ( $IX77909 = $affiliates_db->query( $IX78348, $IX31458 ) ) { $IX26283 = true; $IX80794 = array( 'affiliate_id', 'post_id', 'datetime', 'description', 'ip', 'ipv6', 'user_id', 'amount', 'currency_id', 'data', 'status', 'type', 'reference', 'reference_amount', 'campaign_id', 'hit_id', 'integration' ); $IX77298 = array(); $IX75671 = array(); $IX37381 = array(); foreach( $IX80794 as $IX71164 ) { if ( $IX14340->$IX71164 != $this->$IX71164 ) { $IX77298[] = $IX71164; $IX75671[] = $this->$IX71164; $IX37381[] = $IX14340->$IX71164; } } do_action( 'affiliates_updated_referral', $this->referral_id, $IX77298, $IX75671, $IX37381 ); } } return $IX26283; }

	/**
	 * Delete the entry from the database corresponding to the current object.
	 * Also deletes any related referral items in the database.
	 * Requires this object's referral_id to be set.
	 * @return boolean true on success
	 */
	public function delete() { global $affiliates_db; $IX51292 = false; if ( $this->referral_id !== null ) { $IX56151 = $affiliates_db->get_tablename( 'referral_items' ); $affiliates_db->query( "DELETE FROM $IX56151 " . "WHERE referral_id = %d", intval( $this->referral_id ) ); $IX62755 = $affiliates_db->get_tablename( 'referrals' ); if ( $affiliates_db->query( "DELETE FROM $IX62755 " . "WHERE referral_id = %d", intval( $this->referral_id ) ) ) { $IX51292 = true; do_action( 'affiliates_deleted_referral', $this->referral_id ); } } return $IX51292; }

	/**
	 * Sums all the added referral items and updates the referral's amount.
	 * There must be at least one referral item with an amount for this to
	 * modify the referral's amount.
	 */
	public function compute() { if ( !empty( $this->referral_items ) ) { $this->amount = '0'; foreach( $this->referral_items as $IX45661 ) { if ( $IX45661->amount ) { $this->amount = bcadd( $this->amount, $IX45661->amount, affiliates_get_referral_amount_decimals() ); } } } }
}
Affiliates_Referral::init();
