<?php
/**
 * class-affiliates-dashboard-referrals.php
 *
 * Copyright (c) 2010 - 2019 "kento" Karim Rahimpur www.itthinx.com
 *
 * This code is provided subject to the license granted.
 * Unauthorized use and distribution is prohibited.
 * See COPYRIGHT.txt and LICENSE.txt
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * This header and all notices must be kept intact.
 *
 * @author Karim Rahimpur
 * @package affiliates-pro
 * @since affiliates-pro 4.0.0
 */

if ( !defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Dashboard section: Referrals
 */
class Affiliates_Dashboard_Referrals extends Affiliates_Dashboard_Section_Table {

	protected static $section_order = 300;

	private $search = null;

	protected static $defaults = array(
		'from_date'          => null,
		'thru_date'          => null,
		'per_page'           => self::PER_PAGE_DEFAULT,
		'status'             => array( AFFILIATES_REFERRAL_STATUS_ACCEPTED, AFFILIATES_REFERRAL_STATUS_CLOSED )
	);

	/**
	 * {@inheritDoc}
	 */
	public static function get_section_order() { return self::$section_order; }

	/**
	 * {@inheritDoc}
	 */
	public static function get_name() { return __( 'Referrals', 'affiliates' ); }

	/**
	 * {@inheritDoc}
	 */
	public static function get_key() { return 'referrals'; }

	/**
	 * Filter by user's search query string ...
	 *
	 * @return string
	 */
	public function get_search() { return $this->search; }

	public function get_url( $params = array() ) { $IX10426 = ( is_ssl() ? 'https://' : 'http://' ) . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI']; $IX10426 = remove_query_arg( 'clear_filters', $IX10426 ); $IX10426 = remove_query_arg( 'apply_filters', $IX10426 ); foreach ( $this->url_parameters as $IX84285 ) { $IX10426 = remove_query_arg( $IX84285, $IX10426 ); $IX38517 = null; switch ( $IX84285 ) { case 'per_page' : $IX38517 = $this->get_per_page(); break; case 'from_date' : $IX38517 = $this->get_from_date(); break; case 'thru_date' : $IX38517 = $this->get_thru_date(); break; case 'orderby' : $IX38517 = $this->get_orderby(); break; case 'order' : $IX38517 = $this->get_sort_order(); break; case 'search' : $IX38517 = $this->get_search(); break; } if ( $IX38517 !== null ) { $IX10426 = add_query_arg( $IX84285, $IX38517, $IX10426 ); } } foreach ( $params as $IX48473 => $IX38517 ) { $IX10426 = remove_query_arg( $IX48473, $IX10426 ); if ( $IX38517 !== null ) { $IX10426 = add_query_arg( $IX48473, $IX38517, $IX10426 ); } } return $IX10426; }

	public static function init() { require_once( AFFILIATES_CORE_LIB . '/class-affiliates-date-helper.php' ); }

	public function __construct( $params = array() ) { $this->template = 'dashboard/referrals.php'; $this->require_user_id = true; parent::__construct( $params ); $this->url_parameters = array( 'referrals-page', 'per_page', 'from_date', 'thru_date', 'orderby', 'order', 'search' ); $params = shortcode_atts( self::$defaults, $params ); foreach ( $params as $IX44998 => $IX59451 ) { switch( $IX44998 ) { case 'per_page' : $IX59451 = intval( $IX59451 ); if ( $IX59451 < 0 ) { $IX59451 = self::$defaults['per_page']; } break; case 'status' : if ( !is_array( $IX59451 ) ) { if ( is_string( $IX59451 ) ) { $IX59451 = array_map( 'trim', explode( ',', $IX59451 ) ); } else { $IX59451 = self::$defaults['status']; } } $IX13700 = array(); foreach ( $IX59451 as $IX76896 ) { switch ( $IX76896 ) { case AFFILIATES_REFERRAL_STATUS_ACCEPTED : case AFFILIATES_REFERRAL_STATUS_CLOSED : case AFFILIATES_REFERRAL_STATUS_PENDING : case AFFILIATES_REFERRAL_STATUS_REJECTED : $IX13700[] = $IX76896; break; } } $IX59451 = $IX13700; break; } $params[$IX44998] = $IX59451; } $this->per_page = $params['per_page']; $this->status = $params['status']; $this->column_display_names = array(); $IX33157 = DateHelper::getServerDateTimeZone(); $this->columns['date'] = array( 'title' => __( 'Date', 'affiliates' ), 'description' => sprintf( __( "* Date is given for the server's time zone : %s, which has an offset of %s hours with respect to GMT.", 'affiliates' ), $IX33157->getName(), $IX33157->getOffset( new DateTime() ) / 3600.0 ) ); $this->columns['amount'] = array( 'title' => __( 'Amount', 'affiliates' ), 'description' => __( 'The referral amount or total commission.', 'affiliates' ) ); $this->columns['status'] = array( 'title' => __( 'Status', 'affiliates' ), 'description' => __( 'The current status of the referral.', 'affiliates' ) ); $this->columns['items'] = array( 'title' => __( 'Items', 'affiliates' ), 'description' => __( 'Items related to the referral.', 'affiliates' ) ); }

	public function render() { global $wpdb, $affiliates_db, $affiliates_version; wp_enqueue_script( 'datepicker', AFFILIATES_PLUGIN_URL . 'js/jquery.ui.datepicker.min.js', array( 'jquery', 'jquery-ui-core' ), $affiliates_version ); wp_enqueue_script( 'datepickers', AFFILIATES_PLUGIN_URL . 'js/datepickers.js', array( 'jquery', 'jquery-ui-core', 'datepicker' ), $affiliates_version ); wp_enqueue_style( 'smoothness', AFFILIATES_PLUGIN_URL . 'css/smoothness/jquery-ui-1.8.16.custom.css', array(), $affiliates_version ); $IX47909 = !empty( $_REQUEST['per_page'] ) ? min( max( 1, intval( trim( $_REQUEST['per_page'] ) ) ), self::MAX_PER_PAGE ) : null; if ( $IX47909 !== null ) { $this->per_page = intval( $IX47909 ); } $this->current_page = isset( $_REQUEST['referrals-page'] ) ? max( 0, intval( $_REQUEST['referrals-page'] ) ) : 0; $IX92773 = isset( $_REQUEST['from_date'] ) ? trim( $_REQUEST['from_date'] ) : null; $IX61073 = isset( $_REQUEST['thru_date'] ) ? trim( $_REQUEST['thru_date'] ) : null; $IX55545 = !empty( $_REQUEST['search'] ) ? trim( $_REQUEST['search'] ) : null; if ( strlen( $IX55545 ) === 0 ) { $IX55545 = null; } if ( isset( $_REQUEST['clear_filters'] ) ) { unset( $_REQUEST['from_date'] ); unset( $_REQUEST['thru_date'] ); unset( $_REQUEST['search'] ); $IX92773 = null; $IX61073 = null; $IX55545 = null; } else { if ( !empty( $_REQUEST['from_date'] ) ) { $IX92773 = date( 'Y-m-d', strtotime( $_REQUEST['from_date'] ) ); } else { $IX92773 = null; } if ( !empty( $_REQUEST['thru_date'] ) ) { $IX61073 = date( 'Y-m-d', strtotime( $_REQUEST['thru_date'] ) ); } else { $IX61073 = null; } if ( $IX92773 && $IX61073 ) { if ( strtotime( $IX92773 ) > strtotime( $IX61073 ) ) { $IX61073 = null; } } } $this->from_date = $IX92773; $this->thru_date = $IX61073; $this->search = $IX55545; $this->orderby = isset( $_REQUEST['orderby'] ) ? $_REQUEST['orderby'] : $this->orderby; switch ( $this->orderby ) { case 'referral_id' : case 'reference' : case 'datetime' : case 'post_title' : case 'amount' : case 'currency_id' : case 'status' : break; default : $this->orderby = 'datetime'; } $this->sort_order = isset( $_REQUEST['order'] ) ? $_REQUEST['order'] : $this->sort_order; switch ( $this->sort_order ) { case 'asc' : case 'ASC' : $this->switch_sort_order = 'DESC'; break; case 'desc' : case 'DESC' : $this->switch_sort_order = 'ASC'; break; default: $this->sort_order = 'DESC'; $this->switch_sort_order = 'ASC'; } $IX52245 = null; $IX51410 = null; $this->setup_query_filters( $IX52245, $IX51410 ); $IX61936 = $this->per_page * $this->current_page; $IX93603 = $wpdb->posts; $IX42604 = $affiliates_db->get_tablename( 'affiliates' ); $IX35255 = $affiliates_db->get_tablename( 'referrals' ); $IX51102 = $affiliates_db->get_tablename( 'referral_items' ); $IX13279 = "SELECT SQL_CALC_FOUND_ROWS " . "r.* " . "FROM $IX35255 r " . "LEFT JOIN $IX42604 a ON r.affiliate_id = a.affiliate_id " . "LEFT JOIN $IX93603 p ON r.post_id = p.ID " . "$IX52245"; $IX38453 = "ORDER BY %s %s LIMIT %d OFFSET %d"; $IX78381 = $IX13279 . sprintf( $IX38453, $this->orderby, $this->sort_order, intval( $this->per_page ), intval( $IX61936 ) ); $this->entries = $affiliates_db->get_objects( $IX78381, $IX51410 ); $this->count = intval( $affiliates_db->get_value( "SELECT FOUND_ROWS()" ) ); if ( count( $this->entries ) === 0 && $this->count > 0 ) { $this->current_page = 0; $IX78381 = $IX13279 . sprintf( $IX38453, $this->orderby, $this->sort_order, intval( $this->per_page ), 0 ); $this->entries = $affiliates_db->get_objects( $IX78381, $IX51410 ); $this->count = intval( $affiliates_db->get_value( "SELECT FOUND_ROWS()" ) ); } if ( count( $this->entries ) > 0 ) { foreach ( $this->entries as $IX82766 ) { $IX10979 = $affiliates_db->get_objects( "SELECT * FROM $IX51102 WHERE referral_id = %d", $IX82766->referral_id ); if ( count( $IX10979 ) > 0 ) { foreach ( $IX10979 as $IX80680 ) { if ( isset( $IX80680->object_id ) && $IX80680->object_id !== null && isset( $IX80680->type ) && $IX80680->type !== null ) { $IX41915 = get_posts( array( 'p' => $IX80680->object_id, 'post_type' => $IX80680->type, 'post_status' => 'publish' ) ); if ( count( $IX41915 ) > 0 ) { $IX68697 = array_shift( $IX41915 ); $IX82766->items[] = array( 'referral_item' => $IX80680, 'post' => $IX68697 ); } } } } } } parent::render(); }

	protected function setup_query_filters( &$filters, &$filter_params ) { global $wpdb, $affiliates_db; $IX54491 = $this->get_affiliate_id(); $filters = " WHERE 1=%d "; $filter_params = array( 1 ); if ( $this->from_date ) { $IX78408 = DateHelper::u2s( $this->from_date ); } if ( $this->thru_date ) { $IX71076 = DateHelper::u2s( $this->thru_date, 24*3600 ); } if ( $this->from_date && $this->thru_date ) { $filters .= " AND r.datetime >= %s AND r.datetime <= %s "; $filter_params[] = $IX78408; $filter_params[] = $IX71076; } else if ( $this->from_date ) { $filters .= " AND r.datetime >= %s "; $filter_params[] = $IX78408; } else if ( $this->thru_date ) { $filters .= " AND r.datetime < %s "; $filter_params[] = $IX71076; } $filters .= " AND r.affiliate_id = %d "; $filter_params[] = $IX54491; $IX87276 = ''; if ( is_array( $this->status ) && count( $this->status ) > 0 ) { $IX87276 = " AND ( r.status IS NULL OR r.status IN ('" . implode( "','", array_map( 'esc_sql', $this->status ) ) . "') ) "; $filters .= $IX87276; } $IX51332 = $wpdb->posts; $IX33465 = $affiliates_db->get_tablename( 'referral_items' ); if ( $this->search !== null ) { $filters .= " AND r.referral_id IN ( SELECT DISTINCT ri.referral_id FROM $IX33465 ri LEFT JOIN $IX51332 p ON p.ID = ri.object_id AND ri.type = p.post_type WHERE p.post_title LIKE %s ) "; $filter_params[] = '%' . $wpdb->esc_like( $this->search ) . '%'; } }
}
Affiliates_Dashboard_Referrals::init();
