<?php
/**
 * class-affiliates-dashboard-traffic.php
 *
 * Copyright (c) 2010 - 2019 "kento" Karim Rahimpur www.itthinx.com
 *
 * This code is provided subject to the license granted.
 * Unauthorized use and distribution is prohibited.
 * See COPYRIGHT.txt and LICENSE.txt
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * This header and all notices must be kept intact.
 *
 * @author Karim Rahimpur
 * @package affiliates-pro
 * @since affiliates-pro 4.0.0
 */

if ( !defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * Dashboard section: Referrals
 */
class Affiliates_Dashboard_Traffic extends Affiliates_Dashboard_Section_Table {

	const MAXLENGTH_DEFAULT = 120;

	protected static $section_order = 400;

	private $src_uri = null;

	private $dest_uri = null;

	private $min_referrals = null;

	private $show_dates = true;

	private $show_hits = true;

	private $show_referrals = true;

	private $show_visits = true;

	private $show_src_uris = true;

	private $show_dest_uris = true;

	private $show_filters = true;

	private $show_pagination = true;

	private $get_src_uri_maxlength = self::MAXLENGTH_DEFAULT;

	private $get_dest_uri_maxlength = self::MAXLENGTH_DEFAULT;

	protected static $defaults = array(
		'from_date'          => null,
		'thru_date'          => null,
		'src_uri'            => null,
		'dest_uri'           => null,
		'min_referrals'      => null,
		'show_dates'         => true,
		'show_visits'        => true,
		'show_hits'          => true,
		'show_referrals'     => true,
		'show_src_uris'      => true,
		'show_dest_uris'     => true,
		'show_filters'       => true,
		'show_pagination'    => true,
		'src_uri_maxlength'  => self::MAXLENGTH_DEFAULT,
		'dest_uri_maxlength' => self::MAXLENGTH_DEFAULT,
		'per_page'           => self::PER_PAGE_DEFAULT,
		'status'             => array( AFFILIATES_REFERRAL_STATUS_ACCEPTED, AFFILIATES_REFERRAL_STATUS_CLOSED )
	);

	/**
	 * {@inheritDoc}
	 */
	public static function get_section_order() { return self::$section_order; }

	/**
	 * {@inheritDoc}
	 */
	public static function get_name() { return __( 'Traffic', 'affiliates' ); }

	/**
	 * {@inheritDoc}
	 */
	public static function get_key() { return 'traffic'; }

	/**
	 * Filter by source URI.
	 *
	 * @return string
	 */
	public function get_src_uri() { return $this->src_uri; }

	/**
	 * Filter by destination URI.
	 *
	 * @return string
	 */
	public function get_dest_uri() { return $this->dest_uri; }

	/**
	 * Filter by minimum referrals.
	 *
	 * @return int
	 */
	public function get_min_referrals() { return $this->min_referrals; }

	public function get_url( $params = array() ) { $IX12100 = ( is_ssl() ? 'https://' : 'http://' ) . $_SERVER['HTTP_HOST'] . $_SERVER['REQUEST_URI']; $IX12100 = remove_query_arg( 'clear_filters', $IX12100 ); $IX12100 = remove_query_arg( 'apply_filters', $IX12100 ); foreach ( $this->url_parameters as $IX12060 ) { $IX12100 = remove_query_arg( $IX12060, $IX12100 ); $IX81939 = null; switch ( $IX12060 ) { case 'per_page' : $IX81939 = $this->get_per_page(); break; case 'from_date' : $IX81939 = $this->get_from_date(); break; case 'thru_date' : $IX81939 = $this->get_thru_date(); break; case 'src_uri' : $IX81939 = $this->get_src_uri(); break; case 'dest_uri' : $IX81939 = $this->get_dest_uri(); break; case 'min_referrals' : $IX81939 = $this->get_min_referrals(); break; case 'orderby' : $IX81939 = $this->get_orderby(); break; case 'order' : $IX81939 = $this->get_sort_order(); break; } if ( $IX81939 !== null ) { $IX12100 = add_query_arg( $IX12060, $IX81939, $IX12100 ); } } foreach ( $params as $IX15728 => $IX81939 ) { $IX12100 = remove_query_arg( $IX15728, $IX12100 ); if ( $IX81939 !== null ) { $IX12100 = add_query_arg( $IX15728, $IX81939, $IX12100 ); } } return $IX12100; }

	/**
	 * @return boolean
	 */
	public function get_show_dates() { return $this->show_dates; }

	/**
	 * @return boolean
	 */
	public function get_show_hits() { return $this->show_hits; }

	/**
	 * @return boolean
	 */
	public function get_show_referrals() { return $this->show_referrals; }

	/**
	 * @return boolean
	 */
	public function get_show_visits() { return $this->show_visits; }

	/**
	 * @return boolean
	 */
	public function get_show_src_uris() { return $this->show_src_uris; }

	/**
	 * @return boolean
	 */
	public function get_show_dest_uris() { return $this->show_dest_uris; }

	/**
	 * @return boolean
	 */
	public function get_show_filters() { return $this->show_filters; }

	/**
	 * @return boolean
	 */
	public function get_show_pagination() { return $this->show_pagination; }

	/**
	 * @return int
	 */
	public function get_src_uri_maxlength() { return $this->get_src_uri_maxlength; }

	/**
	 * @return int
	 */
	public function get_dest_uri_maxlength() { return $this->get_dest_uri_maxlength; }

	public static function init() { require_once( AFFILIATES_CORE_LIB . '/class-affiliates-date-helper.php' ); }

	public function __construct( $params = array() ) { $this->template = 'dashboard/traffic.php'; $this->require_user_id = true; parent::__construct( $params ); $this->url_parameters = array( 'traffic-page', 'per_page', 'from_date', 'thru_date', 'src_uri', 'dest_uri', 'min_referrals', 'orderby', 'order' ); $params = shortcode_atts( self::$defaults, $params ); foreach ( $params as $IX86328 => $IX70054 ) { switch( $IX86328 ) { case 'show_dates' : case 'show_visits' : case 'show_hits' : case 'show_referrals' : case 'show_src_uris' : case 'show_dest_uris' : case 'show_filters' : case 'show_pagination' : if ( is_string( $IX70054 ) ) { $IX70054 = strtolower( $IX70054 ); } switch( $IX70054 ) { case 'yes' : case 'true' : case true : $IX70054 = true; break; case 'no' : case 'false' : case false : $IX70054 = false; break; default : $IX70054 = false; } break; case 'src_uri_maxlength' : $IX70054 = intval( $IX70054 ); if ( $IX70054 < 0 ) { $IX70054 = self::$defaults['src_uri_maxlength']; } break; case 'dest_uri_maxlength' : $IX70054 = intval( $IX70054 ); if ( $IX70054 < 0 ) { $IX70054 = self::$defaults['dest_uri_maxlength']; } break; case 'per_page' : $IX70054 = intval( $IX70054 ); if ( $IX70054 < 0 ) { $IX70054 = self::$defaults['per_page']; } break; case 'status' : if ( !is_array( $IX70054 ) ) { if ( is_string( $IX70054 ) ) { $IX70054 = array_map( 'trim', explode( ',', $IX70054 ) ); } else { $IX70054 = self::$defaults['status']; } } $IX36547 = array(); foreach ( $IX70054 as $IX77999 ) { switch ( $IX77999 ) { case AFFILIATES_REFERRAL_STATUS_ACCEPTED : case AFFILIATES_REFERRAL_STATUS_CLOSED : case AFFILIATES_REFERRAL_STATUS_PENDING : case AFFILIATES_REFERRAL_STATUS_REJECTED : $IX36547[] = $IX77999; break; } } $IX70054 = $IX36547; break; } $params[$IX86328] = $IX70054; } $this->show_dates = $params['show_dates']; $this->show_visits = $params['show_visits']; $this->show_hits = $params['show_hits']; $this->show_referrals = $params['show_referrals']; $this->show_src_uris = $params['show_src_uris']; $this->show_dest_uris = $params['show_dest_uris']; $this->show_filters = $params['show_filters']; $this->show_pagination = $params['show_pagination']; $this->src_uri_maxlength = $params['src_uri_maxlength']; $this->dest_uri_maxlength = $params['dest_uri_maxlength']; $this->per_page = $params['per_page']; $this->status = $params['status']; $this->column_display_names = array(); $IX69719 = DateHelper::getServerDateTimeZone(); if ( $this->show_dates ) { $this->columns['date'] = array( 'title' => __( 'Date', 'affiliates' ), 'description' => sprintf( __( "* Date is given for the server's time zone : %s, which has an offset of %s hours with respect to GMT.", 'affiliates' ), $IX69719->getName(), $IX69719->getOffset( new DateTime() ) / 3600.0 ) ); } if ( $this->show_visits ) { $this->columns['visits'] = array( 'title' => __( 'Visits', 'affiliates' ), 'description' => __( 'The number of unique visits.', 'affiliates' ) ); } if ( $this->show_hits ) { $this->columns['hits'] = array( 'title' => __( 'Hits', 'affiliates' ), 'description' => __( 'The number of hits or clicks.', 'affiliates' ) ); } if ( $this->show_referrals ) { $this->columns['referrals'] = array( 'title' => __( 'Referrals', 'affiliates' ), 'description' => __( 'The number of corresponding referrals or conversions.', 'affiliates' ) ); } if ( $this->show_src_uris ) { $this->columns['src_uri'] = array( 'title' => __( 'Source', 'affiliates' ), 'description' => __( 'Where the traffic originated from.', 'affiliates' ) ); } if ( $this->show_dest_uris ) { $this->columns['dest_uri'] = array( 'title' => __( 'Target', 'affiliates' ), 'description' => __( 'Where the traffic lead to.', 'affiliates' ) ); } }

	public function render() { global $affiliates_db, $affiliates_version; wp_enqueue_script( 'datepicker', AFFILIATES_PLUGIN_URL . 'js/jquery.ui.datepicker.min.js', array( 'jquery', 'jquery-ui-core' ), $affiliates_version ); wp_enqueue_script( 'datepickers', AFFILIATES_PLUGIN_URL . 'js/datepickers.js', array( 'jquery', 'jquery-ui-core', 'datepicker' ), $affiliates_version ); wp_enqueue_style( 'smoothness', AFFILIATES_PLUGIN_URL . 'css/smoothness/jquery-ui-1.8.16.custom.css', array(), $affiliates_version ); $IX24022 = !empty( $_REQUEST['per_page'] ) ? min( max( 1, intval( trim( $_REQUEST['per_page'] ) ) ), self::MAX_PER_PAGE ) : null; if ( $IX24022 !== null ) { $this->per_page = intval( $IX24022 ); } $IX37006 = isset( $_REQUEST['traffic-page'] ) ? max( 0, intval( $_REQUEST['traffic-page'] ) ) : 0; $IX51117 = isset( $_REQUEST['from_date'] ) ? trim( $_REQUEST['from_date'] ) : null; $IX37040 = isset( $_REQUEST['thru_date'] ) ? trim( $_REQUEST['thru_date'] ) : null; $IX38930 = isset( $_REQUEST['src_uri'] ) ? trim( $_REQUEST['src_uri'] ) : null; $IX37174 = isset( $_REQUEST['dest_uri'] ) ? trim( $_REQUEST['dest_uri'] ) : null; $IX31612 = isset( $_REQUEST['min_referrals'] ) ? trim( $_REQUEST['min_referrals'] ) : null; if ( isset( $_REQUEST['clear_filters'] ) ) { unset( $_REQUEST['from_date'] ); unset( $_REQUEST['thru_date'] ); unset( $_REQUEST['src_uri'] ); unset( $_REQUEST['dest_uri'] ); unset( $_REQUEST['min_referrals'] ); $IX51117 = null; $IX37040 = null; $IX38930 = null; $IX37174 = null; $IX31612 = null; } else { if ( !empty( $_REQUEST['from_date'] ) ) { $IX51117 = date( 'Y-m-d', strtotime( $_REQUEST['from_date'] ) ); } else { $IX51117 = null; } if ( !empty( $_REQUEST['thru_date'] ) ) { $IX37040 = date( 'Y-m-d', strtotime( $_REQUEST['thru_date'] ) ); } else { $IX37040 = null; } if ( $IX51117 && $IX37040 ) { if ( strtotime( $IX51117 ) > strtotime( $IX37040 ) ) { $IX37040 = null; } } if ( !empty( $_REQUEST['src_uri'] ) ) { $IX38930 = trim( $_REQUEST['src_uri'] ); } else if ( isset( $_REQUEST['src_uri'] ) ) { $IX38930 = null; } if ( !empty( $_REQUEST['dest_uri'] ) ) { $IX37174 = trim( $_REQUEST['dest_uri'] ); } else if ( isset( $_REQUEST['dest_uri'] ) ) { $IX37174 = null; } if ( !empty( $_REQUEST['min_referrals'] ) ) { $IX31612 = max( 0, intval( $_REQUEST['min_referrals'] ) ); } else if ( isset( $_REQUEST['min_referrals'] ) ) { $IX31612 = null; } } $this->from_date = $IX51117; $this->thru_date = $IX37040; $this->src_uri = $IX38930; $this->dest_uri = $IX37174; $this->min_referrals = $IX31612; $this->current_page = $IX37006; $IX31451 = $affiliates_db->get_tablename( 'affiliates' ); $IX50367 = $affiliates_db->get_tablename( 'referrals' ); $IX39250 = $affiliates_db->get_tablename( 'hits' ); $IX37649 = $affiliates_db->get_tablename( 'uris' ); $this->orderby = isset( $_REQUEST['orderby'] ) ? $_REQUEST['orderby'] : $this->orderby; switch ( $this->orderby ) { case 'date' : case 'visits' : case 'hits' : case 'referrals' : case 'src_uri' : case 'dest_uri' : break; default: $this->orderby = 'date'; } $this->sort_order = isset( $_REQUEST['order'] ) ? $_REQUEST['order'] : $this->sort_order; switch ( $this->sort_order ) { case 'asc' : case 'ASC' : $this->switch_sort_order = 'DESC'; break; case 'desc' : case 'DESC' : $this->switch_sort_order = 'ASC'; break; default: $this->sort_order = 'DESC'; $this->switch_sort_order = 'ASC'; } $IX63286 = null; $IX97254 = null; $this->setup_query_filters( $IX63286, $IX97254 ); $IX61168 = ''; if ( $this->min_referrals ) { $IX61168 = " HAVING COUNT(r.hit_id) >= " . intval( $this->min_referrals ). " "; } $IX32954 = $this->per_page * $this->current_page; $IX31680 = "SELECT SQL_CALC_FOUND_ROWS " . "h.date date, " . "su.uri src_uri, " . "du.uri dest_uri, " . "COUNT(distinct h.ip) visits, " . "COUNT(*) hits, " . "COUNT(r.hit_id) referrals " . "FROM $IX39250 h " . "LEFT JOIN $IX31451 a ON h.affiliate_id = a.affiliate_id " . "LEFT JOIN $IX37649 su ON h.src_uri_id = su.uri_id " . "LEFT JOIN $IX37649 du ON h.dest_uri_id = du.uri_id " . "LEFT JOIN $IX50367 r ON r.hit_id = h.hit_id " . "$IX63286 " . "GROUP BY h.affiliate_id, h.date, su.uri_id, du.uri_id " . "$IX61168 "; $IX20245 = "ORDER BY %s %s LIMIT %d OFFSET %d"; $IX42982 = $IX31680 . sprintf( $IX20245, $this->orderby, $this->sort_order, intval( $this->per_page ), intval( $IX32954 ) ); $this->entries = $affiliates_db->get_objects( $IX42982, $IX97254 ); $this->count = intval( $affiliates_db->get_value( "SELECT FOUND_ROWS()" ) ); if ( count( $this->entries ) === 0 && $this->count > 0 ) { $this->current_page = 0; $IX42982 = $IX31680 . sprintf( $IX20245, $this->orderby, $this->sort_order, intval( $this->per_page ), 0 ); $this->entries = $affiliates_db->get_objects( $IX42982, $IX97254 ); $this->count = intval( $affiliates_db->get_value( "SELECT FOUND_ROWS()" ) ); } parent::render(); }

	protected function setup_query_filters( &$filters, &$filter_params ) { global $wpdb; $IX12927 = $this->get_affiliate_id(); $filters = " WHERE 1=%d "; $filter_params = array( 1 ); if ( $this->from_date ) { $IX72548 = DateHelper::u2s( $this->from_date ); } if ( $this->thru_date ) { $IX88285 = DateHelper::u2s( $this->thru_date, 24*3600 ); } if ( $this->from_date && $this->thru_date ) { $filters .= " AND h.datetime >= %s AND h.datetime <= %s "; $filter_params[] = $IX72548; $filter_params[] = $IX88285; } else if ( $this->from_date ) { $filters .= " AND h.datetime >= %s "; $filter_params[] = $IX72548; } else if ( $this->thru_date ) { $filters .= " AND h.datetime < %s "; $filter_params[] = $IX88285; } $filters .= " AND h.affiliate_id = %d "; $filter_params[] = $IX12927; if ( $this->src_uri ) { $filters .= " AND su.uri LIKE '%%%s%%' "; $filter_params[] = $wpdb->esc_like( $this->src_uri ); } if ( $this->dest_uri ) { $filters .= " AND du.uri LIKE '%%%s%%' "; $filter_params[] = $wpdb->esc_like( $this->dest_uri ); } $IX86015 = ''; if ( is_array( $this->status ) && count( $this->status ) > 0 ) { $IX86015 = " AND ( r.status IS NULL OR r.status IN ('" . implode( "','", array_map( 'esc_sql', $this->status ) ) . "') ) "; $filters .= $IX86015; } }
}
Affiliates_Dashboard_Traffic::init();
