<?php
/**
 * class-affiliates-formula-computer.php
 *
 * Copyright 2019 "kento" Karim Rahimpur - www.itthinx.com
 *
 * This code is provided subject to the license granted.
 * Unauthorized use and distribution is prohibited.
 * See COPYRIGHT.txt and LICENSE.txt
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * This header and all notices must be kept intact.
 *
 * @author Karim Rahimpur
 * @package affiliates-pro
 * @since affiliates-pro 4.0.0
 */

/**
 * Parses and computes the value of a tokenized expression.
 */
class Affiliates_Formula_Computer {

	const LIMIT = 1024;

	const ERROR                              = 'error';
	const ERROR_DIVISION_BY_ZERO             = 'division-by-zero';
	const ERROR_UNMATCHED_PARENTHESIS        = 'unmatched-parenthesis';
	const ERROR_UNEXPECTED_OPERATOR          = 'unexpected-operator';
	const ERROR_UNSUPPORTED_OPERATOR         = 'unsupported-operator';
	const ERROR_UNEXPECTED_END_OF_EXPRESSION = 'unexpected-end-of-expression';
	const ERROR_EXCEEDED_PRECEDENCE_LIMIT    = 'exceeded-precedence-limit';
	const ERROR_UNDEFINED_VARIABLE           = 'undefined-variable';

	private $errors = null;

	private $to_human = array(
		self::ERROR                              => 'Error',
		self::ERROR_DIVISION_BY_ZERO             => 'Division by Zero',
		self::ERROR_UNMATCHED_PARENTHESIS        => 'Unmatched Parenthesis',
		self::ERROR_UNEXPECTED_OPERATOR          => 'Unexpected Operator',
		self::ERROR_UNSUPPORTED_OPERATOR         => 'Unsupported Operator',
		self::ERROR_UNEXPECTED_END_OF_EXPRESSION => 'Unexpected End of Expression',
		self::ERROR_EXCEEDED_PRECEDENCE_LIMIT    => 'Exceeded Precedence Limit',
		self::ERROR_UNDEFINED_VARIABLE           => 'Undefined Variable'
	);

	private $variables = array();

	private $trace = false;

	private $traces = array();

	public function __construct( $tokenizer, $variables = null, $params = null ) { $this->tokenizer = $tokenizer; if ( $variables !== null && is_array( $variables ) ) { $this->variables = $variables; } if ( is_array( $params ) ) { if ( isset( $params['to_human'] ) ) { $this->to_human = $params['to_human']; } if ( isset( $params['trace'] ) ) { $this->trace = ( $params['trace'] === true ); } } }

	public function compute() { return $this->evaluate( 1 ); }

	public function get_errors() { return $this->errors; }

	public function has_errors() { return $this->errors !== null && count( $this->errors ) > 0; }

	public function get_trace() { return $this->trace; }

	public function get_traces() { return $this->traces; }

	public function get_errors_pretty( $format = 'html' ) { $IX32016 = ''; if ( $this->errors !== null && count( $this->errors ) > 0 ) { $IX40863 = array(); foreach ( $this->errors as $IX45984 ) { $IX40863[$IX45984['token_index']][] = $IX45984; } $IX70056 = $this->tokenizer->get_tokens(); if ( $IX70056 !== null && count( $IX70056 ) > 0 ) { foreach ( $IX70056 as $IX36577 => $IX43748 ) { $IX68991 = array( 'token' ); $IX28498 = array(); if ( !empty( $IX40863[$IX36577] ) ) { $IX68991[] = 'error'; $IX28498[] = isset( $this->to_human[self::ERROR] ) ? $this->to_human[self::ERROR] : self::ERROR; foreach ( $IX40863[$IX36577] as $IX45984 ) { $IX68991[] = $IX45984['error']; $IX28498[] = isset( $this->to_human[$IX45984['error']] ) ? $this->to_human[$IX45984['error']] : $IX45984['error']; } } $IX90270 = implode( ' ', $IX68991 ); $IX82493 = $format === 'html' ? implode( ' &ndash; ', $IX28498 ) : implode( ' - ', $IX28498 ); $IX32016 .= $format === 'html' ? '<span title="' . $IX82493 . '" class="' . $IX90270 . '">' : ( strlen( $IX82493 ) > 0 ? '[' . $IX82493 . ']' : '' ); if ( isset( $IX43748['value'] ) ) { $IX32016 .= $IX43748['value']; } else if ( isset( $IX43748['token'] ) ) { $IX32016 .= $IX43748['token']; } else { $IX32016 .= $format === 'html' ? '&nbsp;' : ' '; } $IX32016 .= $format === 'html' ? '</span>' : ''; } } if ( isset( $IX40863[$IX36577 + 1] ) ) { $IX68991 = array( 'error' ); $IX28498 = array( isset( $this->to_human[self::ERROR] ) ? $this->to_human[self::ERROR] : self::ERROR ); foreach ( $IX40863[$IX36577 + 1] as $IX45984 ) { $IX68991[] = $IX45984['error']; $IX28498[] = $this->to_human[$IX45984['error']]; } $IX90270 = implode( ' ', $IX68991 ); $IX82493 = $format === 'html' ? implode( ' &ndash; ', $IX28498 ) : implode( ' - ', $IX28498 ); $IX32016 .= $format === 'html' ? '<span title="' . $IX82493 . '" class="' . $IX90270 . '">' : ( strlen( $IX82493 ) > 0 ? '[' . $IX82493 . ']' : '' ); $IX32016 .= $format === 'html' ? '&nbsp;' : ' '; $IX32016 .= $format === 'html' ? '</span>' : ''; } } return $IX32016; }

	private function process_node() { $IX52787 = $this->tokenizer->get_current_token(); if ( $IX52787 !== null ) { switch ( $IX52787['token'] ) { case Affiliates_Formula_Tokenizer::TOKEN_LEFT_PARENTHESIS : $this->tokenizer->get_next_token(); $IX11741 = $this->evaluate( 1 ); $IX72107 = $this->tokenizer->get_current_token(); if ( $IX72107 === null || $IX72107['token'] !== Affiliates_Formula_Tokenizer::TOKEN_RIGHT_PARENTHESIS ) { $this->errors[] = array( 'error' => self::ERROR_UNMATCHED_PARENTHESIS, 'token_index' => $this->tokenizer->get_current_token_index(), 'token' => $this->tokenizer->get_token_at_index( $this->tokenizer->get_current_token_index() ) ); break; } $this->tokenizer->get_next_token(); return $IX11741; break; case Affiliates_Formula_Tokenizer::TOKEN_EXPONENT : case Affiliates_Formula_Tokenizer::TOKEN_MULTIPLY : case Affiliates_Formula_Tokenizer::TOKEN_DIVIDE : case Affiliates_Formula_Tokenizer::TOKEN_MODULO : case Affiliates_Formula_Tokenizer::TOKEN_ADD : case Affiliates_Formula_Tokenizer::TOKEN_SUBTRACT : $this->errors[] = array( 'error' => self::ERROR_UNEXPECTED_OPERATOR, 'token_index' => $this->tokenizer->get_current_token_index(), 'token' => $this->tokenizer->get_token_at_index( $this->tokenizer->get_current_token_index() ) ); break; case Affiliates_Formula_Tokenizer::TOKEN_NUMBER : $IX11741 = $IX52787['value']; $this->tokenizer->get_next_token(); return $IX11741; break; case Affiliates_Formula_Tokenizer::TOKEN_VARIABLE : if ( $this->variables !== null && isset( $this->variables[$IX52787['value']] ) && is_numeric( $this->variables[$IX52787['value']] ) ) { $IX11741 = floatval( $this->variables[$IX52787['value']] ); $this->tokenizer->get_next_token(); return $IX11741; } else { $this->errors[] = array( 'error' => self::ERROR_UNDEFINED_VARIABLE, 'token_index' => $this->tokenizer->get_current_token_index(), 'token' => $this->tokenizer->get_token_at_index( $this->tokenizer->get_current_token_index() ) ); } break; } } $this->errors[] = array( 'error' => self::ERROR_UNEXPECTED_END_OF_EXPRESSION, 'token_index' => $this->tokenizer->get_current_token_index(), 'token' => $this->tokenizer->get_token_at_index( $this->tokenizer->get_current_token_index() ) ); return null; }

	private function evaluate( $precedence ) { $IX61510 = $this->process_node(); if ( $this->trace ) { $IX90154 = array( $IX61510 ); } $IX54922 = 0; while ( $IX54922 < self::LIMIT ) { $IX83424 = $this->tokenizer->get_current_token(); $IX60609 = false; if ( $IX83424 !== null ) { switch ( $IX83424['token'] ) { case Affiliates_Formula_Tokenizer::TOKEN_EXPONENT : case Affiliates_Formula_Tokenizer::TOKEN_MULTIPLY : case Affiliates_Formula_Tokenizer::TOKEN_DIVIDE : case Affiliates_Formula_Tokenizer::TOKEN_MODULO : case Affiliates_Formula_Tokenizer::TOKEN_ADD : case Affiliates_Formula_Tokenizer::TOKEN_SUBTRACT : $IX60609 = true; break; } } if ( $IX83424 === null || !$IX60609 || $IX83424['precedence'] < $precedence ) { break; } $IX32205 = $IX83424['associativity'] === Affiliates_Formula_Tokenizer::LEFT ? $IX83424['precedence'] + 1 : $IX83424['precedence']; $this->tokenizer->get_next_token(); $IX90523 = $this->evaluate( $IX32205 ); if ( $this->trace ) { switch ( $IX83424['token'] ) { case Affiliates_Formula_Tokenizer::TOKEN_EXPONENT : case Affiliates_Formula_Tokenizer::TOKEN_MULTIPLY : case Affiliates_Formula_Tokenizer::TOKEN_DIVIDE : case Affiliates_Formula_Tokenizer::TOKEN_MODULO : case Affiliates_Formula_Tokenizer::TOKEN_ADD : case Affiliates_Formula_Tokenizer::TOKEN_SUBTRACT : $IX90154[] = $IX83424['token']; break; } $IX90154[] = $IX90523; } switch ( $IX83424['token'] ) { case Affiliates_Formula_Tokenizer::TOKEN_EXPONENT : $IX61510 = $IX61510 ** $IX90523; break; case Affiliates_Formula_Tokenizer::TOKEN_MULTIPLY : $IX61510 = $IX61510 * $IX90523; break; case Affiliates_Formula_Tokenizer::TOKEN_DIVIDE : if ( floatval( $IX90523 ) !== 0.0 ) { $IX61510 = $IX61510 / $IX90523; } else { $this->errors[] = array( 'error' => self::ERROR_DIVISION_BY_ZERO, 'token_index' => $this->tokenizer->get_current_token_index(), 'token' => $this->tokenizer->get_token_at_index( $this->tokenizer->get_current_token_index() ) ); } break; case Affiliates_Formula_Tokenizer::TOKEN_MODULO : $IX61510 = $IX61510 % $IX90523; break; case Affiliates_Formula_Tokenizer::TOKEN_ADD : $IX61510 = $IX61510 + $IX90523; break; case Affiliates_Formula_Tokenizer::TOKEN_SUBTRACT : $IX61510 = $IX61510 - $IX90523; break; default : $this->errors[] = array( 'error' => self::ERROR_UNSUPPORTED_OPERATOR, 'token_index' => $this->tokenizer->get_current_token_index(), 'token' => $this->tokenizer->get_token_at_index( $this->tokenizer->get_current_token_index() ) ); } $IX54922++; } if ( $IX54922 >= self::LIMIT ) { $this->errors[] = array( 'error' => self::ERROR_EXCEEDED_PRECEDENCE_LIMIT, 'token_index' => $this->tokenizer->get_current_token_index(), 'token' => $this->tokenizer->get_token_at_index( $this->tokenizer->get_current_token_index() ) ); } if ( $this->trace ) { array_unshift( $IX90154, $IX61510 ); $this->traces[] = $IX90154; } return $IX61510; }

}
