<?php
/**
 * class-affiliates-formula-tokenizer.php
 *
 * Copyright 2019 "kento" Karim Rahimpur - www.itthinx.com
 *
 * This code is provided subject to the license granted.
 * Unauthorized use and distribution is prohibited.
 * See COPYRIGHT.txt and LICENSE.txt
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * This header and all notices must be kept intact.
 *
 * @author Karim Rahimpur
 * @package affiliates-pro
 * @since affiliates-pro 4.0.0
 */

/**
 * Arithmetic formula tokenizer.
 */
class Affiliates_Formula_Tokenizer {
	const ASSOCIATIVITY  = 'associativity';
	const PRECEDENCE     = 'precedence';
	const LEFT           = 'left';
	const RIGHT          = 'right';

	const TOKEN_EXPONENT = '**';
	const TOKEN_MULTIPLY = '*';
	const TOKEN_DIVIDE   = '/';
	const TOKEN_MODULO   = '%';
	const TOKEN_ADD      = '+';
	const TOKEN_SUBTRACT = '-';

	const TOKEN_LEFT_PARENTHESIS  = '(';
	const TOKEN_RIGHT_PARENTHESIS = ')';

	const TOKEN_NUMBER      = 'number';
	const TOKEN_VARIABLE    = 'variable';
	const TOKEN_PLACEHOLDER = 'placeholder';

	static $operators = array(
		self::TOKEN_EXPONENT => array(
			self::ASSOCIATIVITY => self::RIGHT,
			self::PRECEDENCE    => 3,
		),
		self::TOKEN_MULTIPLY => array(
			self::ASSOCIATIVITY => self::LEFT,
			self::PRECEDENCE    => 2,
		),
		self::TOKEN_DIVIDE => array(
			self::ASSOCIATIVITY => self::LEFT,
			self::PRECEDENCE    => 2,
		),
		self::TOKEN_MODULO => array(
			self::ASSOCIATIVITY => self::LEFT,
			self::PRECEDENCE    => 2,
		),
		self::TOKEN_ADD => array(
			self::ASSOCIATIVITY => self::LEFT,
			self::PRECEDENCE    => 1
		),
		self::TOKEN_SUBTRACT => array(
			self::ASSOCIATIVITY => self::LEFT,
			self::PRECEDENCE    => 1,
		)
	);

	private $expression = null;

	private $current_token = null;

	private $tokens = null;

	public function __construct( $expression ) { if ( is_string( $expression ) ) { $this->expression = $expression; $this->tokenize(); } }

	public function tokenize() { if ( $this->expression !== null ) { $IX82395 = preg_replace( '/\s+/', '', $this->expression ); $IX63079 = null; preg_match_all( '/' . '\d+\.\d*' . '|' . '\d*\.\d+' . '|' . '\d+' . '|' . '{[a-zA-Z_][a-zA-Z0-9_]*}' . '|' . '[a-zA-Z_][a-zA-Z0-9_]*' . '|' . '\(' . '|' . '\)' . '|' . '\*\*' . '|' . '\*' . '|' . '\/' . '|' . '%' . '|' . '\+' . '|' . '\-' . '/', $IX82395, $IX63079 ); $this->tokens = array(); $IX24302 = 0; foreach ( $IX63079[0] as $IX69168 ) { $IX69121 = null; $IX59846 = null; $IX29498 = null; $IX63288 = null; switch ( $IX69168 ) { case self::TOKEN_EXPONENT : case self::TOKEN_MULTIPLY : case self::TOKEN_DIVIDE : case self::TOKEN_MODULO : case self::TOKEN_ADD : case self::TOKEN_SUBTRACT : $IX63288 = $IX69168; $IX59846 = self::$operators[$IX69168][self::ASSOCIATIVITY]; $IX29498 = self::$operators[$IX69168][self::PRECEDENCE]; break; case self::TOKEN_LEFT_PARENTHESIS : $IX63288 = $IX69168; $IX24302++; break; case self::TOKEN_RIGHT_PARENTHESIS : $IX63288 = $IX69168; $IX24302--; break; default : if ( is_numeric( $IX69168 ) ) { $IX63288 = self::TOKEN_NUMBER; $IX69121 = floatval( $IX69168 ); break; } else { if ( strpos( $IX69168, '{' ) !== false ) { $IX63288 = self::TOKEN_PLACEHOLDER; $IX69121 = substr( $IX69168, 1, strlen( $IX69168 ) - 2 ); } else { $IX63288 = self::TOKEN_VARIABLE; $IX69121 = $IX69168; } } } if ( $IX63288 !== null ) { $this->tokens[] = array( 'token' => $IX63288, 'value' => $IX69121, 'associativity' => $IX59846, 'precedence' => $IX29498, 'level' => $IX24302 ); } } } }

	public function to_string() { $IX38910 = array(); if ( $this->tokens !== null ) { foreach ( $this->tokens as $IX92422 ) { if ( isset( $IX92422['value'] ) ) { $IX38910[] = $IX92422['value']; } else if ( isset( $IX92422['token'] ) ) { $IX38910[] = $IX92422['token']; } } } $IX38910 = implode( ' ', $IX38910 ); return $IX38910; }

	public function get_tokens() { return $this->tokens; }

	public function get_next_token() { $IX95042 = null; if ( $this->tokens !== null && count( $this->tokens ) > 0 ) { if ( $this->current_token === null ) { $this->current_token = 0; } else { $this->current_token++; } if ( $this->current_token < count( $this->tokens ) ) { $IX95042 = $this->tokens[$this->current_token]; } } return $IX95042; }

	public function get_current_token() { $IX63753 = null; if ( $this->tokens !== null && count( $this->tokens ) > 0 ) { if ( $this->current_token === null ) { $this->current_token = 0; } if ( $this->current_token < count( $this->tokens ) ) { $IX63753 = $this->tokens[$this->current_token]; } } return $IX63753; }

	public function get_current_token_index() { return $this->current_token; }

	/**
	 * Returns the token at the given index or null if there is none.
	 *
	 * @param int $token_index 0, 1, ...
	 *
	 * @return array|null
	 */
	public function get_token_at_index( $token_index ) { $IX84834 = null; if ( $this->tokens !== null && count( $this->tokens ) > 0 ) { if ( $token_index < count( $this->tokens ) ) { $IX84834 = $this->tokens[$token_index]; } } return $IX84834; }
}
