<?php
/**
 * class-affiliates-notifications-extended.php
 *
 * Copyright 2012 "kento" Karim Rahimpur - www.itthinx.com
 *
 * This code is provided subject to the license granted.
 * Unauthorized use and distribution is prohibited.
 * See COPYRIGHT.txt and LICENSE.txt
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * This header and all notices must be kept intact.
 *
 * @author Karim Rahimpur
 * @package affiliates-pro
 * @since affiliates-pro 2.16.0
 */

/**
 * Notifications
 */
class Affiliates_Notifications_Extended extends Affiliates_Notifications {

	const NONCE = 'aff-admin-menu';
	const SETTINGS = 'aff-settings';

	const REGISTRATION_SUBJECT                = 'registration_subject';
	const REGISTRATION_MESSAGE                = 'registration_message';
	const REGISTRATION_PENDING_SUBJECT                = 'registration_pending_subject';
	const REGISTRATION_PENDING_MESSAGE                = 'registration_pending_message';
	const ADMIN_REGISTRATION_ENABLED          = 'aff_notify_admin';
	const ADMIN_REGISTRATION_ENABLED_DEFAULT  = true;
	const ADMIN_REGISTRATION_SUBJECT          = 'admin_registration_subject';
	const ADMIN_REGISTRATION_MESSAGE          = 'admin_registration_message';
	const ADMIN_REGISTRATION_PENDING_SUBJECT  = 'admin_registration_pending_subject';
	const ADMIN_REGISTRATION_PENDING_MESSAGE  = 'admin_registration_pending_message';

	const AFFILIATE_PENDING_TO_ACTIVE_SUBJECT                = 'affiliate_pending_to_active_subject';
	const AFFILIATE_PENDING_TO_ACTIVE_MESSAGE                = 'affiliate_pending_to_active_message';

	const NOTIFY_ADMIN           = 'notify_admin';
	const NOTIFY_ADMIN_EMAIL     = 'notify_admin_email';
	const NOTIFY_ADMIN_STATUS    = 'notify_admin_status';
	const ADMIN_SUBJECT          = 'admin_subject';
	const ADMIN_MESSAGE          = 'admin_message';
	const ADMIN_DEFAULT_SUBJECT  = 'Referral';
	const ADMIN_DEFAULT_MESSAGE  = 'A referral has been credited to the affiliate [affiliate_name] (ID [affiliate_id]) on <a href="[site_url]">[site_title]</a>.<br/>';

	const NOTIFY_AFFILIATE        = 'notify_affiliate';
	const NOTIFY_AFFILIATE_STATUS = 'notify_affiliate_status';
	const SUBJECT          = 'subject';
	const MESSAGE          = 'message';
	const DEFAULT_SUBJECT  = 'Referral';
	const DEFAULT_MESSAGE  =
'Hi [affiliate_name],<br/>
A referral has been credited to you on <a href="[site_url]">[site_title]</a>.<br/>
<br/>
Greetings,<br/>
[site_title]<br/>
[site_url]<br/>';

	/**
	 * Overrides parent's singleton constructor.
	 */
	protected function __construct() { parent::__construct(); self::init(); }

	public function get_admin_class() { return 'Affiliates_Admin_Notifications_Extended'; }

	/**
	 * Adds hooks and actions for notifications.
	 */
	public static function init() { parent::init(); $IX46589 = get_option( 'affiliates_notifications', array() ); $IX36223 = isset( $IX46589[self::NOTIFY_ADMIN] ) ? $IX46589[self::NOTIFY_ADMIN] : false; $IX98480 = isset( $IX46589[self::NOTIFY_AFFILIATE] ) ? $IX46589[self::NOTIFY_AFFILIATE] : false; if ( $IX36223 || $IX98480 ) { add_action( 'affiliates_referral', array( self::get_instance(), 'affiliates_referral' ) ); add_action( 'affiliates_updated_referral', array( self::get_instance(), 'affiliates_updated_referral' ), 10, 4 ); } }

	/**
	 * Registers the affiliates-admin-notifications css style.
	 */
	public static function admin_init() { wp_register_style( 'affiliates-pro-admin-notifications', AFFILIATES_PRO_PLUGIN_URL . 'css/affiliates_admin_notifications.css' ); }

	public static function affiliates_new_affiliate_registration_subject( $subject, $params ) { $IX22778 = get_option( 'affiliates_notifications', array() ); $IX57549 = get_option( 'aff_status', null ); switch( $IX57549 ) { case 'pending' : $IX95660 = isset( $IX22778[self::ADMIN_REGISTRATION_PENDING_SUBJECT] ) ? $IX22778[self::ADMIN_REGISTRATION_PENDING_SUBJECT] : self::get_default( self::DEFAULT_ADMIN_REGISTRATION_PENDING_SUBJECT ); break; case 'active' : default : $IX95660 = isset( $IX22778[self::ADMIN_REGISTRATION_SUBJECT] ) ? $IX22778[self::ADMIN_REGISTRATION_SUBJECT] : self::get_default( self::DEFAULT_ADMIN_REGISTRATION_ACTIVE_SUBJECT ); } $IX14380 = self::get_registration_tokens( $params ); $subject = self::substitute_tokens( stripslashes( $IX95660 ), $IX14380 ); return $subject; }

	public static function  affiliates_new_affiliate_registration_message( $message, $params ) { $IX71058 = get_option( 'affiliates_notifications', array() ); $IX47836 = get_option( 'aff_status', null ); switch( $IX47836 ) { case 'pending' : $IX73742 = isset( $IX71058[self::ADMIN_REGISTRATION_PENDING_MESSAGE] ) ? $IX71058[self::ADMIN_REGISTRATION_PENDING_MESSAGE] : self::get_default( self::DEFAULT_ADMIN_REGISTRATION_PENDING_MESSAGE ); break; case 'active' : default : $IX73742 = isset( $IX71058[self::ADMIN_REGISTRATION_MESSAGE] ) ? $IX71058[self::ADMIN_REGISTRATION_MESSAGE] : self::get_default( self::DEFAULT_ADMIN_REGISTRATION_ACTIVE_MESSAGE ); } $IX81518 = self::get_registration_tokens( $params ); $message = self::substitute_tokens( stripslashes( $IX73742 ), $IX81518 ); return $message; }

	public static function affiliates_new_affiliate_registration_headers( $headers = '', $params = array() ) { $headers .= 'Content-type: text/html; charset="' . get_option( 'blog_charset' ) . '"' . "\r\n"; return $headers; }

	public static function affiliates_new_affiliate_user_registration_subject( $subject, $params ) { $IX12130 = get_option( 'affiliates_notifications', array() ); $IX90726 = get_option( 'aff_status', null ); switch ( $IX90726 ) { case 'pending' : $IX40652 = isset( $IX12130[self::REGISTRATION_PENDING_SUBJECT] ) ? $IX12130[self::REGISTRATION_PENDING_SUBJECT] : self::get_default( self::DEFAULT_REGISTRATION_PENDING_SUBJECT ); break; case 'active': default: $IX40652 = isset( $IX12130[self::REGISTRATION_SUBJECT] ) ? $IX12130[self::REGISTRATION_SUBJECT] : self::get_default( self::DEFAULT_REGISTRATION_ACTIVE_SUBJECT ); break; } $IX34020 = self::get_registration_tokens( $params ); $subject = self::substitute_tokens( stripslashes( $IX40652 ), $IX34020 ); return $subject; }

	public static function affiliates_new_affiliate_user_registration_message( $message, $params ) { $IX76878 = get_option( 'affiliates_notifications', array() ); $IX89010 = get_option( 'aff_status', null ); switch ( $IX89010 ) { case 'pending' : $IX28214 = isset( $IX76878[self::REGISTRATION_PENDING_MESSAGE] ) ? $IX76878[self::REGISTRATION_PENDING_MESSAGE] : self::get_default( self::DEFAULT_REGISTRATION_PENDING_MESSAGE ); break; case 'active': default: $IX28214 = isset( $IX76878[self::REGISTRATION_MESSAGE] ) ? $IX76878[self::REGISTRATION_MESSAGE] : self::get_default( self::DEFAULT_REGISTRATION_ACTIVE_MESSAGE ); break; } $IX55148 = self::get_registration_tokens( $params ); $message = self::substitute_tokens( stripslashes( $IX28214 ), $IX55148 ); return $message; }

	public static function affiliates_new_affiliate_user_registration_headers( $headers = '', $params = array() ) { $headers .= 'Content-type: text/html; charset="' . get_option( 'blog_charset' ) . '"' . "\r\n"; return $headers; }

	public static function affiliates_updated_affiliate_status_subject( $subject, $params, $old_status, $new_status ) { $IX43271 = get_option( 'affiliates_notifications', array() ); $IX90120 = ''; switch ( $old_status ) { case 'pending' : switch ( $new_status ) { case 'active' : $IX90120 = isset( $IX43271[self::AFFILIATE_PENDING_TO_ACTIVE_SUBJECT] ) ? $IX43271[self::AFFILIATE_PENDING_TO_ACTIVE_SUBJECT] : self::get_default( self::DEFAULT_AFFILIATE_PENDING_TO_ACTIVE_SUBJECT ); break; } break; } $IX50346 = self::get_registration_tokens( $params ); $subject = self::substitute_tokens( stripslashes( $IX90120 ), $IX50346 ); return $subject; }

	public static function  affiliates_updated_affiliate_status_message( $message, $params, $old_status, $new_status ) { $IX29211 = get_option( 'affiliates_notifications', array() ); $IX75019 = ''; switch ( $old_status ) { case 'pending' : switch ( $new_status ) { case 'active' : $IX75019 = isset( $IX29211[self::AFFILIATE_PENDING_TO_ACTIVE_MESSAGE] ) ? $IX29211[self::AFFILIATE_PENDING_TO_ACTIVE_MESSAGE] : self::get_default( self::DEFAULT_AFFILIATE_PENDING_TO_ACTIVE_MESSAGE ); break; } break; } $IX16422 = self::get_registration_tokens( $params ); $message = self::substitute_tokens( stripslashes( $IX75019 ), $IX16422 ); return $message; }

	public static function affiliates_updated_affiliate_status_headers( $headers = '', $params = array(), $old_status = '', $new_status = '' ) { $headers .= 'Content-type: text/html; charset="' . get_option( 'blog_charset' ) . '"' . "\r\n"; return $headers; }

	private static function get_registration_tokens( $params ) { $IX87260 = array(); foreach( $params as $IX56790 => $IX28109 ) { if ( is_string( $IX28109 ) ) { $IX87260[$IX56790] = $IX28109; } } $IX87260['site_title'] = wp_specialchars_decode( get_bloginfo( 'blogname' ), ENT_QUOTES ); $IX87260['site_url'] = home_url(); if ( isset( $params['user_id'] ) ) { $IX88368 = intval( $params['user_id'] ); if ( ( $IX34261 = get_user_by( 'id', $IX88368 ) ) ) { require_once AFFILIATES_CORE_LIB . '/class-affiliates-settings.php'; require_once AFFILIATES_CORE_LIB . '/class-affiliates-settings-registration.php'; $IX68996 = Affiliates_Settings_Registration::get_fields(); if ( !empty( $IX68996 ) ) { foreach( $IX68996 as $IX82257 => $IX98727 ) { if ( $IX98727['enabled'] ) { $IX71212 = isset( $IX98727['type'] ) ? $IX98727['type'] : 'text'; switch( $IX82257 ) { case 'user_login' : $IX28109 = $IX34261->user_login; break; case 'user_email' : $IX28109 = $IX34261->user_email; break; case 'user_url' : $IX28109 = $IX34261->user_url; break; case 'password' : $IX28109 = ''; break; default : $IX28109 = get_user_meta( $IX88368, $IX82257 , true ); } if ( !isset( $IX87260[$IX82257] ) ) { $IX87260[$IX82257] = esc_attr( stripslashes( $IX28109 ) ); } } } } } } $IX87260 = apply_filters( 'affiliates_registration_tokens', $IX87260 ); return $IX87260; }

	private static function substitute_tokens( $s, $tokens ) { foreach ( $tokens as $IX40561 => $IX62302 ) { if ( key_exists( $IX40561, $tokens ) ) { $IX93193 = $tokens[$IX40561]; $s = str_replace( "[" . $IX40561 . "]", $IX93193, $s ); } } return $s; }

	public static function affiliates_referral( $referral_id ) { global $affiliates_db; $IX33362 = $affiliates_db->get_tablename( 'referrals' ); if ( $IX77505 = $affiliates_db->get_objects( "SELECT * FROM $IX33362 WHERE referral_id = %d", intval( $referral_id ) ) ) { if ( isset( $IX77505[0] ) ) { $IX49108 = $IX77505[0]; if ( $IX92650 = affiliates_get_affiliate( $IX49108->affiliate_id ) ) { $IX91939 = get_option( 'affiliates_notifications', array() ); $IX26312 = isset( $IX91939[self::NOTIFY_ADMIN] ) ? $IX91939[self::NOTIFY_ADMIN] : false; $IX66629 = isset( $IX91939[self::NOTIFY_ADMIN_EMAIL] ) ? $IX91939[self::NOTIFY_ADMIN_EMAIL] : ''; $IX19472 = isset( $IX91939[self::NOTIFY_AFFILIATE] ) ? $IX91939[self::NOTIFY_AFFILIATE] : false; if ( $IX26312 || $IX19472 ) { require_once( dirname( AFFILIATES_PRO_FILE ) . '/lib/ext/includes/class-affiliates-mail.php' ); $IX39372 = new Affiliates_Mail(); $IX39372->mailer = 'wp_mail'; $IX39372->charset = get_option( 'blog_charset' ); $IX39799 = wp_specialchars_decode( get_bloginfo( 'blogname' ), ENT_QUOTES ); $IX45966 = home_url(); $IX34620 = apply_filters( 'affiliates_notifications_tokens', array( 'site_title' => $IX39799, 'site_url' => $IX45966, 'affiliate_name' => wp_filter_nohtml_kses( $IX92650['name'] ), 'affiliate_id' => $IX92650['affiliate_id'], 'affiliate_email' => $IX92650['email'], 'referral_status' => $IX49108->status, 'referral_id' => $IX49108->referral_id, 'referral_amount' => $IX49108->amount, 'referral_currency_id' => $IX49108->currency_id, 'referral_type' => $IX49108->type, 'referral_reference' => $IX49108->reference ) ); $IX42721 = array(); $IX26973 = array(); if ( !empty( $IX49108->data ) ) { $IX26973 = unserialize( $IX49108->data ); if ( $IX26973 && is_array( $IX26973 ) ) { $IX42721 = array_keys( $IX26973 ); } } $IX42721 = apply_filters( 'affiliates_notifications_data_tokens', $IX42721, $IX34620 ); $IX26973 = apply_filters( 'affiliates_notifications_data', $IX26973, $IX42721, $IX34620 ); if ( $IX26312 ) { $IX33543 = empty( $IX66629 ) ? get_bloginfo( 'admin_email' ) : $IX66629; if ( !empty( $IX33543 ) ) { $IX63304 = isset( $IX91939[self::NOTIFY_ADMIN_STATUS] ) ? $IX91939[self::NOTIFY_ADMIN_STATUS] : array( AFFILIATES_REFERRAL_STATUS_ACCEPTED ); if ( in_array( $IX49108->status, $IX63304 ) ) { $IX11867 = isset( $IX91939[self::ADMIN_SUBJECT] ) ? $IX91939[self::ADMIN_SUBJECT] : self::ADMIN_DEFAULT_SUBJECT; $IX79893 = isset( $IX91939[self::ADMIN_MESSAGE] ) ? $IX91939[self::ADMIN_MESSAGE] : self::ADMIN_DEFAULT_MESSAGE; $IX39372->mail( $IX33543, stripslashes( wp_filter_nohtml_kses( $IX11867 ) ), stripslashes( wp_filter_post_kses( $IX79893 ) ), $IX34620, $IX42721, $IX26973 ); } } } if ( $IX19472 ) { if ( !empty( $IX92650['email'] ) ) { $IX23338 = isset( $IX91939[self::NOTIFY_AFFILIATE_STATUS] ) ? $IX91939[self::NOTIFY_AFFILIATE_STATUS] : array( AFFILIATES_REFERRAL_STATUS_ACCEPTED ); if ( in_array( $IX49108->status, $IX23338 ) ) { $IX10433 = isset( $IX91939[self::SUBJECT] ) ? $IX91939[self::SUBJECT] : self::DEFAULT_SUBJECT; $IX57066 = isset( $IX91939[self::MESSAGE] ) ? $IX91939[self::MESSAGE] : self::DEFAULT_MESSAGE; $IX39372->mail( $IX92650['email'], stripslashes( wp_filter_nohtml_kses( $IX10433 ) ), stripslashes( wp_filter_post_kses( $IX57066 ) ), $IX34620, $IX42721, $IX26973 ); } } } } } } } }

	public static function affiliates_updated_referral( $referral_id, $keys, $values, $old_values ) { $IX50965 = count( $keys ); for( $IX45425 = 0; $IX45425 < $IX50965; $IX45425++ ) { if ( $keys[$IX45425] == 'status' ) { $IX84419 = $values[$IX45425]; $IX97814 = $old_values[$IX45425]; if ( ( $IX84419 == AFFILIATES_REFERRAL_STATUS_ACCEPTED ) && ( $IX97814 == AFFILIATES_REFERRAL_STATUS_PENDING ) ) { self::affiliates_referral( $referral_id ); } } } }

	public static function affiliates_updated_affiliate_status( $affiliate_id, $old_status, $new_status ) { $IX82000 = get_option( 'affiliates_notifications', array() ); if ( ( $old_status == 'pending' ) && ( $new_status == 'active' ) ) { $IX45249 = affiliates_get_affiliate_user ( $affiliate_id ); $IX30676 = wp_specialchars_decode( get_option( 'blogname' ), ENT_QUOTES ); if ( $IX70818 = get_userdata( $IX45249 ) ) { if ( get_option( 'aff_notify_affiliate_user', 'yes' ) != 'no' ) { $IX41342 = isset( $IX82000[self::AFFILIATE_PENDING_TO_ACTIVE_SUBJECT] ) ? $IX82000[self::AFFILIATE_PENDING_TO_ACTIVE_SUBJECT] : self::get_default( self::DEFAULT_AFFILIATE_PENDING_TO_ACTIVE_SUBJECT ); $IX28184 = isset( $IX82000[self::AFFILIATE_PENDING_TO_ACTIVE_MESSAGE] ) ? $IX82000[self::AFFILIATE_PENDING_TO_ACTIVE_MESSAGE] : self::get_default( self::DEFAULT_AFFILIATE_PENDING_TO_ACTIVE_MESSAGE ); $IX27291 = array( 'user_id' => $IX45249, 'user' => $IX70818, 'username' => $IX70818->user_login, 'site_login_url' => wp_login_url(), 'blogname' => $IX30676 ); @wp_mail( $IX70818->user_email, apply_filters( 'affiliates_updated_affiliate_status_subject', $IX41342, $IX27291, $old_status, $new_status ), apply_filters( 'affiliates_updated_affiliate_status_message', $IX28184, $IX27291, $old_status, $new_status ), apply_filters( 'affiliates_updated_affiliate_status_headers', '', $IX27291, $old_status, $new_status ) ); } } } }

}
