<?php
/**
 * campaigns-entry.php
 *
 * Copyright (c) 2010 - 2019 "kento" Karim Rahimpur www.itthinx.com
 *
 * This code is provided subject to the license granted.
 * Unauthorized use and distribution is prohibited.
 * See COPYRIGHT.txt and LICENSE.txt
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * This header and all notices must be kept intact.
 *
 * @author Karim Rahimpur
 * @package affiliates-enterprise
 * @since affiliates-enterprise 4.0.0
 *
 * This is a template file. You can customize it by copying it
 * into the appropriate subfolder of your theme:
 *
 *   mytheme/affiliates/dashboard/campaigns-entry.php
 *
 * It is highly recommended to use a child theme for such customizations.
 * Child themes are suitable to keep things up-to-date when the parent
 * theme is updated, while any customizations in the child theme are kept.
 */

if ( !defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @var Affiliates_Dashboard_Campaigns $section Section object available for use in the template.
 * @var array $entry Current campaign entry data available for use in the template.
 * @var int $index Index number of the current campaign entry: 0, 1, 2, ... < $section->get_per_page()
 * @var int $count Total number of campaign entries.
 */

$class = ( $index === 0 ? 'first ' : '' ) . ( ( $index + 1 ) % 2 === 0 ? 'even' : 'odd' );
$class .= ( $index + 1 === $count ? ' last' : '' );
$columns = $section->get_columns();
?>
<div class="cell name full <?php echo $class; ?>" data-heading="<?php echo esc_attr( $columns['name']['title'] ); ?>">
	<?php echo esc_html( stripslashes( $entry->name ) ); ?>
</div>
<div class="cell description full <?php echo $class; ?>" data-heading="<?php echo esc_attr( $columns['description']['title'] ); ?>">
	<?php echo esc_html( stripslashes( $entry->description ) ); ?>
</div>
<div class="cell hits one <?php echo $class; ?>" data-heading="<?php echo esc_attr( $columns['hits']['title'] ); ?>">
	<?php echo esc_html( stripslashes( $entry->hits ) ); ?>
</div>
<div class="cell visits two <?php echo $class; ?>"data-heading="<?php echo esc_attr( $columns['visits']['title'] ); ?>" >
	<?php echo esc_html( stripslashes( $entry->visits ) ); ?>
</div>
<div class="cell referrals three <?php echo $class; ?>" data-heading="<?php echo esc_attr( $columns['referrals']['title'] ); ?>">
	<?php echo esc_html( stripslashes( $entry->referrals ) ); ?>
</div>
<div class="cell ratio four <?php echo $class; ?>" data-heading="<?php echo esc_attr( $columns['ratio']['title'] ); ?>">
	<?php echo esc_html( stripslashes( $entry->ratio ) ); ?>
</div>
<div class="cell totals full <?php echo $class; ?>" data-heading="<?php echo esc_attr( $columns['totals']['title'] ); ?>">
	<?php if ( count( $entry->totals ) > 0 ) : ?>
		<div class="campaign-totals">
		<?php foreach ( $entry->totals as $currency_id => $amount ) : ?>
			<?php $display_amount = sprintf( '%.' .affiliates_get_referral_amount_decimals( 'display' ) . 'f', $amount ); ?>
			<div class="campaign-total">
				<span class="campaign-total-currency"><?php echo esc_html( $currency_id ); ?> <span class="campaign-total-amount"><?php echo esc_html( $display_amount ); ?></span>
			</div>
		<?php endforeach; ?>
		</div>
	<?php else : ?>
		<div class="campaign-totals"><?php echo '&mdash;'; ?></div>
	<?php endif; ?>
</div>
<div class="cell url one-three <?php echo $class; ?>" data-heading="<?php echo esc_attr( $columns['url']['title'] ); ?>">
	<?php echo esc_html( stripslashes( $entry->url ) ); ?>
</div>
<div class="cell campaign_id four <?php echo $class; ?>" data-heading="<?php echo esc_attr( $columns['campaign_id']['title'] ); ?>">
	<?php echo esc_html( stripslashes( $entry->campaign_id ) ); ?>
</div>
