<?php
/**
 * campaigns.php
 *
 * Copyright (c) 2010 - 2019 "kento" Karim Rahimpur www.itthinx.com
 *
 * This code is provided subject to the license granted.
 * Unauthorized use and distribution is prohibited.
 * See COPYRIGHT.txt and LICENSE.txt
 *
 * This code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 *
 * This header and all notices must be kept intact.
 *
 * @author Karim Rahimpur
 * @package affiliates-enterprise
 * @since affiliates-enterprise 4.0.0
 *
 * This is a template file. You can customize it by copying it
 * into the appropriate subfolder of your theme:
 *
 *   mytheme/affiliates/dashboard/campaigns.php
 *
 * It is highly recommended to use a child theme for such customizations.
 * Child themes are suitable to keep things up-to-date when the parent
 * theme is updated, while any customizations in the child theme are kept.
 */

if ( !defined( 'ABSPATH' ) ) {
	exit;
}

/**
 * @var Affiliates_Dashboard_Campaigns $section Section object available for use in the template.
 */
?>
<?php if ( $section->is_management() ) : ?>
	<div class="dashboard-section dashboard-section-campaigns">
		<div class="campaign-management-container">
			<?php echo Affiliates_Campaign_Table::render( array( 'affiliate_id' => $section->get_affiliate_id(), 'columns' => 'cb,campaign_id,name,actions' ) ); ?>
			<div class="campaign-management-back">
				<a class="button management" href="<?php echo esc_url( $section->get_url ( array( 'management' => '0', 'orderby_comp' => null ) ) ); ?>" title="<?php esc_html_e( 'Leave the campaign management.', 'affiliates' ); ?>"><?php esc_html_e( 'Back', 'affiliates' ); ?></a>
			</div>
		</div>
	</div>
<?php else : ?>
<h2><?php esc_html_e( 'Campaigns', 'affiliates' ); ?></h2>
<?php
	//
	// Render the campaigns filter form
	//
?>
<div class="dashboard-section dashboard-section-campaigns">
	<?php
		//
		// Campaign Management Access
		//
	?>
	<div class="campaign-management-container">
		<a class="button management" href="<?php echo esc_url( $section->get_url( array( 'management' => '1', 'orderby_comp' => null ) ) ); ?>" title="<?php esc_html_e( 'Access campaign management here to create, edit and remove campaigns.', 'affiliates' ); ?>"><?php esc_html_e( 'Manage Campaigns', 'affiliates' ); ?></a>
	</div>
	<?php
		//
		// Filters
		//
	?>
	<form id="setfilters" class="filters capsule-container" action="" method="post">
		<div class="capsule full">
			<label for="search" class="search-filter"><?php esc_html_e( 'Search', 'affiliates' ); ?></label>
			<input class="input-text search-filter" title="<?php echo esc_attr( __( 'Search for a term in campaigns', 'affiliates' ) ); ?>" name="search" type="text" value="<?php echo esc_attr( stripslashes( $section->get_search() ) ); ?>" placeholder="<?php esc_html_e( 'Search for &hellip;', 'affiliates' ); ?>"/>
		</div>
		<div class="capsule full">
			<label for="orderby_comp" class="orderby-filter"><?php esc_html_e( 'Sort by &hellip;', 'affiliates' ); ?></label>
			<?php $orderby_selected = strtolower( $section->get_orderby() . '-' . $section->get_sort_order() ); ?>
			<select name="orderby_comp">
				<option <?php echo ( $orderby_selected === 'name-asc' ? ' selected="selected" ' : '' ); ?> value="name-asc"><?php esc_html_e( 'Name', 'affiliates' ); ?></option>
				<option <?php echo ( $orderby_selected === 'name-desc' ? ' selected="selected" ' : '' ); ?> value="name-desc"><?php esc_html_e( 'Name (reverse)', 'affiliates' ); ?></option>
				<option <?php echo ( $orderby_selected === 'ratio-desc' ? ' selected="selected" ' : '' ); ?> value="ratio-desc"><?php esc_html_e( 'Highest Conversion Rate', 'affiliates' ); ?></option>
				<option <?php echo ( $orderby_selected === 'ratio-asc' ? ' selected="selected" ' : '' ); ?> value="ratio-asc"><?php esc_html_e( 'Lowest Conversion Rate', 'affiliates' ); ?></option>
				<option <?php echo ( $orderby_selected === 'referrals-desc' ? ' selected="selected" ' : '' ); ?> value="referrals-desc"><?php esc_html_e( 'Most Referrals', 'affiliates' ); ?></option>
				<option <?php echo ( $orderby_selected === 'referrals-asc' ? ' selected="selected" ' : '' ); ?> value="referrals-asc"><?php esc_html_e( 'Least Referrals', 'affiliates' ); ?></option>
				<option <?php echo ( $orderby_selected === 'visits-desc' ? ' selected="selected" ' : '' ); ?> value="visits-desc"><?php esc_html_e( 'Most Visits', 'affiliates' ); ?></option>
				<option <?php echo ( $orderby_selected === 'visits-asc' ? ' selected="selected" ' : '' ); ?> value="visits-asc"><?php esc_html_e( 'Least Visits', 'affiliates' ); ?></option>
				<option <?php echo ( $orderby_selected === 'hits-desc' ? ' selected="selected" ' : '' ); ?> value="hits-desc"><?php esc_html_e( 'Most Hits', 'affiliates' ); ?></option>
				<option <?php echo ( $orderby_selected === 'hits-asc' ? ' selected="selected" ' : '' ); ?> value="hits-asc"><?php esc_html_e( 'Least Hits', 'affiliates' ); ?></option>
				<option <?php echo ( $orderby_selected === 'campaign_id-asc' ? ' selected="selected" ' : '' ); ?> value="campaign_id-asc"><?php esc_html_e( 'ID', 'affiliates' ); ?></option>
				<option <?php echo ( $orderby_selected === 'campaign_id-desc' ? ' selected="selected" ' : '' ); ?> value="campaign_id-desc"><?php esc_html_e( 'ID (reverse)', 'affiliates' ); ?></option>
			</select>
		</div>
		<div class="filter-buttons">
			<input class="button apply-button" type="submit" name="apply_filters" value="<?php esc_html_e( 'Apply', 'affiliates' ); ?>"/>
			<input class="button clear-button" type="submit" name="clear_filters" value="<?php esc_html_e( 'Clear', 'affiliates' ); ?>"/>
		</div>
	</form>
	<?php
		//
		// Filter styles
		//
	?>
	<style type="text/css">
	.dashboard-section-campaigns form.filters {
		background-color: #f2f2f2;
		border-radius: 4px;
		margin: 4px;
		padding: 4px;
	}
	.dashboard-section-campaigns .capsule-container {
		width: 100%;
		display: grid;
		grid-template-columns: repeat(auto-fill, 25%);
	}
	.dashboard-section-campaigns .capsule-container .capsule.half.left {
		grid-column: 1 / 3;
	}
	.dashboard-section-campaigns .capsule-container .capsule.half.right {
		grid-column: 3 / 5;
	}
	.dashboard-section-campaigns .capsule-container .capsule.full {
		grid-column: 1 / 5;
	}
	.dashboard-section-campaigns .capsule-container .capsule {
		display: flex;
		padding: 4px;
		margin: 4px;
		align-items: center;
	}
	.dashboard-section-campaigns .capsule-container .capsule label {
		padding: 0 4px;
	}
	.dashboard-section-campaigns .capsule-container .capsule input {
		flex: 1;
		overflow: hidden;
	}
	.dashboard-section-campaigns .filters .filter-buttons {
		display: flex;
		flex-wrap: wrap;
		margin: 4px;
		grid-column: 1 / 5;
	}
	.dashboard-section-campaigns .filters .filter-buttons input {
		flex-shrink: 1;
		margin: 4px;
	}
	</style>
<?php
	//
	// Render the campaigns section
	//
?>
<div class="campaigns-container">
	<?php // Render the entries ?>
	<?php $entries = $section->get_entries(); ?>
	<?php if ( count( $entries ) > 0 ) :
		$i = 0;
		foreach ( $entries as $entry ) :
			Affiliates_Templates::include_template(
				'dashboard/campaigns-entry.php',
				array(
					'section' => $section,
					'entry'   => $entry,
					'index'   => $i,
					'count'   => count( $entries )
				)
			);
			$i++;
		endforeach;
	?>
	<?php else : ?>
		<div class="cell odd full"><?php esc_html_e( 'There are no results.', 'affiliates' ); ?></div>
	<?php endif; ?>

</div><?php // .campaigns-container ?>
<?php
	//
	// Render the section navigation
	//
?>
<?php if ( $section->get_count() > 0 ) : ?>
	<div class="section-navigation">
		<?php if ( $section->get_current_page() > 0 ) : ?>
			<a style="margin: 4px;" class="button" href="<?php echo esc_url( $section->get_url( array( 'campaigns-page' => $section->get_current_page() - 1 ) ) ); ?>"><?php echo esc_html_x( 'Previous', 'Label used to show previous page of affiliate referral results', 'affiliates' ); ?></a>
		<?php endif; ?>
		<?php if ( $section->get_current_page() < $section->get_pages() - 1 ) : ?>
			<a style="margin: 4px;" class="button" href="<?php echo esc_url( $section->get_url( array( 'campaigns-page' => $section->get_current_page() + 1 ) ) ); ?>"><?php echo esc_html_x( 'Next', 'Label used to show next page of affiliate referral results', 'affiliates' ); ?></a>
		<?php endif; ?>
	</div>
	<div class="section-navigation-options">
		<form action="<?php echo esc_url( $section->get_url( array( 'per_page' => null ) ) ); ?>" method="post">
			<label class="row-count">
				<?php esc_html_e( 'Results per page', 'affiliates' ); ?>
				<input class="per-page" name="per_page" type="text" value="<?php echo esc_attr( $section->get_per_page() ); ?>" placeholder="<?php echo esc_attr( $section::PER_PAGE_DEFAULT ); ?>" />
				<input class="button" type="submit" value="<?php esc_attr_e( 'Apply', 'affiliates' ); ?>"/>
			</label>
		</form>
	</div>
<?php endif; ?>
</div><?php // .dashboard-section-campaigns ?>
<?php endif; // not management ?>
<?php
	//
	// Section styles
	//
?>
<style type="text/css">
.dashboard-section-campaigns .campaigns-container {
	width: 100%;
	display: grid;
	grid-template-columns: 25% 25% 25% 25%;
	margin: 4px;
	border: 2px solid #e0e0e0;
	border-radius: 4px;
}
.dashboard-section-campaigns .campaigns-container .cell {
	word-break: break-word;
	padding: 4px;
	color: #171717;
	background-color: #ffffff;
	padding: 4px;
}
.dashboard-section-campaigns .campaigns-container .cell.full {
	grid-column: 1 / -1;
}
.dashboard-section-campaigns .campaigns-container .cell.half.left {
	grid-column: 1 / 3;
}
.dashboard-section-campaigns .campaigns-container .cell.half.right {
	grid-column: 3 / -1;
}
.dashboard-section-campaigns .campaigns-container .cell.one {
	grid-column: 1;
}
.dashboard-section-campaigns .campaigns-container .cell.two {
	grid-column: 2;
}
.dashboard-section-campaigns .campaigns-container .cell.three {
	grid-column: 3;
}
.dashboard-section-campaigns .campaigns-container .cell.four {
	grid-column: 4;
}
.dashboard-section-campaigns .campaigns-container .cell.one-three {
	grid-column: 1 / 4;
}

.dashboard-section-campaigns .campaigns-container .name {
	font-size: larger;
	border-bottom: 1px solid #dadada;
}
.dashboard-section-campaigns .campaigns-container .description {
}
.dashboard-section-campaigns .campaigns-container .hits,
.dashboard-section-campaigns .campaigns-container .visits,
.dashboard-section-campaigns .campaigns-container .referrals,
.dashboard-section-campaigns .campaigns-container .ratio {
	text-align: center;
}
.dashboard-section-campaigns .campaigns-container .totals {
	text-align: center;
}
.dashboard-section-campaigns .campaigns-container .totals::before {
	text-align: left;
}
.dashboard-section-campaigns .campaigns-container .url:not(.last),
.dashboard-section-campaigns .campaigns-container .campaign_id:not(.last) {
	border-bottom: 1px solid #9e9e9e;
}
.dashboard-section-campaigns .campaigns-container .campaign_id {
	text-align: right;
}

.dashboard-section-campaigns .campaigns-container .heading {
	background-color: #ffffff;
	color: 171717;
	font-weight: bold;
	word-break: break-word;
	border-bottom: 4px solid #9e9e9e;
}
.dashboard-section-campaigns .campaigns-container .odd {
	background-color: #ffffff;
	color: #252525;
}
.dashboard-section-campaigns .campaigns-container .even {
	background-color: #f0f0f0;
	color: #171717;
}
.dashboard-section-campaigns .section-navigation-options {
	margin: 32px 4px;
}
.dashboard-section-campaigns .section-navigation-options input.per-page {
	width: 4em;
}

.dashboard-section-campaigns .campaigns-container .cell::before {
	display: block;
	font-size: smaller;
	font-weight: bolder;
	content: attr(data-heading);
}

@media only screen and (max-width: 768px) {
	.dashboard-section-campaigns .campaigns-container .heading {
		border: none;
	}
	.dashboard-section-campaigns .campaigns-container {
		grid-template-columns: 100%;
	}
	.dashboard-section-campaigns .campaigns-container .cell,
	.dashboard-section-campaigns .campaigns-container .cell.full,
	.dashboard-section-campaigns .campaigns-container .cell.half.left,
	.dashboard-section-campaigns .campaigns-container .cell.half.right,
	.dashboard-section-campaigns .campaigns-container .cell.one,
	.dashboard-section-campaigns .campaigns-container .cell.two,
	.dashboard-section-campaigns .campaigns-container .cell.three,
	.dashboard-section-campaigns .campaigns-container .cell.four,
	.dashboard-section-campaigns .campaigns-container .cell.one-three {
		grid-column: 1;
		text-align: initial;
	}
	.dashboard-section-campaigns .campaigns-container .heading {
		font-size: small;
	}
	.dashboard-section-campaigns .campaigns-container .cell::before {
		display: block;
		font-size: smaller;
		font-weight: bolder;
		content: attr(data-heading);
	}
	.dashboard-section-campaigns .campaigns-container .url:not(.last) {
		border-bottom: unset;
	}
}
</style>
<?php
	//
	// Campaign item styles
	//
?>
<style type="text/css">
	.dashboard-section-campaigns .campaign-item {
		width: 100%;
		display: grid;
		grid-template-columns: 75% 25%;
		margin: 4px;
	}
	.dashboard-section-campaigns .campaign-item-title {
		grid-column: 1;
	}
	.dashboard-section-campaigns .campaign-item-amount {
		word-break: break-word;
		grid-column: 2;
	}
</style>
<?php
	//
	// Campaign-management styles
	//
?>
<style type="text/css">
.dashboard-section-campaigns .campaign-management-container {
	margin: 32px 4px;
}
.dashboard-section-campaigns .campaign-management-container .button {
	white-space: nowrap;
}
.dashboard-section-campaigns .campaign-management-container a.management {
	position: relative;
	overflow: visible;
}
.dashboard-section-campaigns .campaign-management-container a.management:hover::before {
	display: block;
	font-size: smaller;
	font-weight:normal;
	content: attr(title);
	word-break: break-word;
	position: absolute;
	color: #171717;
	background-color: #f0f0f0;
	width: 240px;
	height: auto;
	white-space: normal;
	padding: 4px;
	border-radius: 4px;
	border: 1px solid #9e9e9e;
	right: -256px;
	top: 0px;
}

.dashboard-section-campaigns .campaign-management-container .tablenav {
	margin: 4px;
	display: flex;
	flex-wrap: wrap;
}
.dashboard-section-campaigns .campaign-management-container .tablenav div {
	display: inline-block;
	vertical-align: middle;
	margin: 4px;
	flex-grow: 1;
}
.dashboard-section-campaigns .campaign-management-container .tablenav div.actions > * {
	display: inline-block;
	vertical-align: middle;
}
</style>
